import QtQuick 1.1
import com.nokia.meego 1.0
import "pages"

Page {
    id: mainPage
    tools: tabBarLayout

    property bool needDisableToolbar : tabGroup.currentTab.needDisableToolbar
    onNeedDisableToolbarChanged: appWindow.showToolBar = !needDisableToolbar

    ToolBarLayout {
        id: tabBarLayout
        visible: false

//        ToolIcon {
//            platformIconId: "toolbar-back"
//        }

        // define a button row
        ButtonRow {
            id: tabBarLayoutBtnRow
            checkedButton: tabBtnProfile
            TabButton { id: tabBtnProfile;  tab: tabProfile;    iconSource: "icons/vk-profile.png" }
            TabButton { id: tabBtnFriends;  tab: tabFriends;    iconSource: "icons/vk-friends.png" }
            TabButton { id: tabBtnMessages; tab: tabMessages;   iconSource: "icons/vk-messages.png" }
            TabButton { id: tabBtnPhotos;   tab: tabPhotos;     iconSource: "icons/vk-photos.png" }
            TabButton { id: tabBtnAudio;    tab: tabAudio;      iconSource: "icons/vk-audio.png" }
            TabButton { id: tabBtnVideo;    tab: tabVideo;      iconSource: "icons/vk-video.png" }
        }

        ToolIcon {
            platformIconId: "toolbar-view-menu"
            onClicked: (mainMenu.status === DialogStatus.Closed) ? mainMenu.open() : mainMenu.close()
        }
    }

    Menu {
        id: mainMenu
        //visualParent: pageStack
        MenuLayout {
            MenuItem {
                text: "О программе"
                onClicked: aboutDialog.open()
            }
            MenuItem {
                text: "Сменить пользователя"
                onClicked: logoutQueryDialog.open()
            }
            MenuItem {
                text: "Выйти"
                onClicked: Qt.quit()
            }
        }
    }

    Dialog {
        id: aboutDialog
        title: Item {
            id: aboutDlgTitleField
            height: aboutDialog.platformStyle.titleBarHeight
            width: parent.width
            Image {
                id: supplement
                source: "icons/VeeK.png"
                height: parent.height - 10
                width: 75
                fillMode: Image.PreserveAspectFit
                anchors.leftMargin: 5
                anchors.rightMargin: 5
            }

            Label {
                id: titleLabel
                anchors.left: supplement.right
                anchors.verticalCenter: aboutDlgTitleField.verticalCenter
                font.capitalization: Font.MixedCase
                color: "white"
                text: vkLoaderService.getFullAppName()
            }
        }

        content:Item {
            id: name
            anchors {
                left: parent.left
                right: parent.right
            }
            height: childrenRect.height
            Text {
                anchors {
                    left: parent.left
                    right: parent.right
                }
                id: text
                font.pixelSize: 26
                color: "white"
                text: "\n\nАльтернативный клиент ВКонтакте\nАвтор: Алексей Шутов\nСпециально для allnokia.ru\n\nВерсия Qt " + vkAppService.getQtVersion()
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
            }
        }
    }

    QueryDialog {
        id: logoutQueryDialog

        icon: "image://theme/icon-m-transfer-error"
        titleText: "Сменить пользователя?"
        message: "Вы действительно хотите сменить пользователя "
                 + "и выйти из программы?\nПри следующем запуске "
                 + "потребуется заново ввести логин и пароль."
        acceptButtonText: "Да"
        rejectButtonText: "Нет"

        onAccepted: {
            vkLoaderService.forgetUserLoginInfo()
            Qt.quit();
        }
    }

    // define tab group with pages
    TabGroup {
        id: tabGroup
        anchors { left: parent.left; right: parent.right; top: parent.top; bottom: parent.bottom }

        currentTab: tabProfile

        VkPageProfile {
            id: tabProfile
        }

        VkPageFriends {
            id: tabFriends
        }

        VkPageMessages {
            id: tabMessages
            isPageActive: tabGroup.currentTab === tabMessages
        }

        VkPagePhotos {
            id: tabPhotos
        }

        VkPageAudio {
            id: tabAudio
        }

        VkPageVideo {
            id: tabVideo
        }

        onCurrentTabChanged: currentTab.handleTabActivated()
    }

    // subpage interconnections
    function switchTo(tabToSwitch)
    {
        tabGroup.currentTab = tabToSwitch
    }
    function returnToProfileTab()
    {
        switchTo(tabProfile)
    }
    function showUserPage(uid)
    {
        tabProfile.showOtherUserPage(uid)
        switchTo(tabProfile)
    }
    function showOwnerFriendPage()
    {
        switchTo(tabFriends)
    }
    function showUserFriendPage(uid)
    {
        // tabFriends.showUser....
        switchTo(tabFriends)
    }
    function showOwnerMessagePage()
    {
        tabMessages.showOwnerMessages()
        switchTo(tabMessages)
    }
    function showDialogWith(uid)
    {
        tabMessages.showDialogWith(uid)
        switchTo(tabMessages)
    }
    function showOwnerPhotoPage()
    {
        tabPhotos.showOwnerPhotos()
        switchTo(tabPhotos)
    }
    function showUserPhotoPage(uid)
    {
        tabPhotos.showOtherUserPhotos(uid)
        switchTo(tabPhotos)
    }
    function showExternalViewPhotoPage(idx)
    {
        tabPhotos.showExternalPhotos(idx)
        switchTo(tabPhotos)
    }
    function showOwnerAudioPage()
    {
        tabAudio.showOwnerAudio()
        switchTo(tabAudio)
    }
    function showUserAudioPage(uid)
    {
        tabAudio.showOtherUserAudio(uid)
        switchTo(tabAudio)
    }
    function showExternalViewAudioPage(idx, startPlay, showPage)
    {
        tabAudio.showExternalAudio(idx, startPlay)
        if (showPage) {
            switchTo(tabAudio)
        }
    }
    function showOwnerVideoPage()
    {
        tabVideo.showOwnerVideo()
        switchTo(tabVideo)
    }
    function showUserVideoPage(uid)
    {
        tabVideo.showOtherUserVideo(uid)
        switchTo(tabVideo)
    }
    function showExternalViewVideoPage(vid, owner_id, title, description, duration, image, player, likes_count, likes_user_likes, likes_can_like, likes_busy, likes_valid)
    {
        tabVideo.showExternalVideo(vid, owner_id, title, description, duration, image, player, likes_count, likes_user_likes, likes_can_like, likes_busy, likes_valid)
        switchTo(tabVideo)
    }
}
