// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import VkService 1.0

Page {

    property int currentStep: 0
    property int maxSteps: 9
    property bool isLongTask: false
    property string taskName: ""
    property bool isLoaded: false
    property bool isFirstTime: true
    property bool haveLoginPage: false
    property variant mainPageComponent

    Loader {
        id: mainPageLoader
        visible: false

        onStatusChanged: if (status === Loader.Null) {
                             console.log("mainPageLoader status Null")
                         } else if (status === Loader.Ready) {
                             console.log("mainPageLoader status Ready")
                         } else if (status === Loader.Loading) {
                             console.log("mainPageLoader status Loading")
                         } else if (status === Loader.Error) {
                            console.log("mainPageLoader status Error")
                            console.log("can't load main page item")
                            Qt.quit()
                         }
        onLoaded: processMainPageLoaded()
    }

    function processLoadStep()
    {
        isLongTask = false;
        taskName = ""

        // do loading
        var doNextStep = true
        switch (currentStep) {
            case 0:
                // load cookies
                taskName = "Загрузка..."
                isFirstTime = vkLoaderService.initCookies()
                break
            case 1:
                // show license
                taskName = "Загрузка..."
                if (isFirstTime) {
                    console.log("is first time run, show license...")
                    var licensePageComponent = Qt.createComponent("VkLicense.qml")
                    if (licensePageComponent.status === Component.Ready) {
                        var licensePage = licensePageComponent.createObject(pageStack.parent);
                        pageStack.push(licensePage)
                        licensePage.acceptClicked.connect(processLicenseAccepted)
                        doNextStep = false
                    } else {
                        console.log("can't load license component")
                        Qt.quit()
                    }
                }
                break
            case 2:
                isLongTask = true
                taskName = "Авторизация ВКонтакте..."
                vkLoginService.initialize()
                vkLoginService.loginSuccess.connect(processLoginSuccess)
                vkLoginService.needLoginPage.connect(processNeedLoginPage)
                doNextStep = false
                break
            case 3:
                taskName = "Инициализация кэша..."
                vkLoaderService.preloadNamedCache("avatar")
                break
            case 4:
                taskName = "Инициализация кэша..."
                vkLoaderService.preloadNamedCache("photo")
                break
            case 5:
                taskName = "Инициализация кэша..."
                vkLoaderService.preloadNamedCache("audio")
                break
            case 6:
                taskName = "Запуск приложения..."
                vkAppService.setMonthNamesGen(["января", "февраля", "марта", "апреля", "мая", "июня", "июля", "августа", "сентября", "октября", "ноября", "декабря"])
                vkAppService.setTimeWords("секунду", "секунды", "секунд", "минуту", "минуты", "минут", "только что", "сегодня", "вчера", "назад");
                break
            case 7:
                taskName = "Запуск приложения..."
                console.log("create UI: Main Page item")
                mainPageLoader.source = "MainPage.qml"
                doNextStep = false
                console.log("Main Page item created")
                break
            case 8:
                taskName = "Запуск приложения..."
                console.log("create UI: push Main Page item to page stack")
                if (mainPageLoader.status === Loader.Ready) {
                    var mainPage = mainPageLoader.item
                    mainPage.parent = pageStack.parent
                    pageStack.push(mainPage)
                    console.log("UI created")
                } else {
                    console.log("wrong initialization")
                    Qt.quit()
                }
                break
            case 9:
                console.log("run application")
                break
        }

        // detect done
        if (currentStep === maxSteps) {
            console.log("...loading finished...")
            isLoaded = true
            return false
        }
        if (!doNextStep) {
            console.log("...stop loading...")
        }
        currentStep++
        return doNextStep
    }

    function processLicenseAccepted() {
        console.log("processLicenseAccepted")
        var licensePage = pageStack.pop(null, true)
        licensePage.destroy()
        loaderTimer.start()
    }
    function processLoginSuccess() {
        console.log("processLoginSuccess")
        if (haveLoginPage) {
            haveLoginPage = false
            var loginPage = pageStack.pop(null, true)
            loginPage.destroy()
        }
        vkLoginService.deinitialize()
        loaderTimer.start()
    }
    function processNeedLoginPage() {
        console.log("processNeedLoginPage")
        var loginPageComponent = Qt.createComponent("VkLogin.qml")
        if (loginPageComponent.status === Component.Ready) {
            var loginPage = loginPageComponent.createObject(pageStack.parent);
            pageStack.push(loginPage)
            haveLoginPage = true
        } else {
            console.log("can't load login component")
            Qt.quit()
        }
    }
    function processMainPageLoaded() {
        console.log("processMainPageLoaded")
        loaderTimer.start()
    }

    ProgressBar {
        id: progressLoad
        width: parent.width - 50
        anchors {
            verticalCenter: parent.verticalCenter
            horizontalCenter: parent.horizontalCenter
        }

        minimumValue: 0
        maximumValue: maxSteps
        value: currentStep
    }
    Label {
        id: loaderLabel
        anchors {
            bottom: progressLoad.top
            bottomMargin: 15
            horizontalCenter: parent.horizontalCenter
        }
        text: "Инициализация..."
    }
    Label {
        id: loaderTaskName
        anchors {
            top: progressLoad.bottom
            left: parent.left
            topMargin: 15
            leftMargin: 20
        }

        text: taskName
        color: "darkgrey"
    }
    BusyIndicator {
        anchors {
            verticalCenter: loaderTaskName.verticalCenter
            left: loaderTaskName.right
            leftMargin: 20
        }
        running: isLongTask
        visible: isLongTask
    }

    Timer {
        id: loaderTimer
        interval: 50
        running: true
        repeat: true

        onTriggered: {
            stop();
            if (processLoadStep() && !isLoaded) {
                start()
            }
        }
    }

    // Services
    VkLoaderService {
        id: vkLoaderService
    }
    VkLoginService {
        id: vkLoginService
    }

    Component.onCompleted: {
        loaderTimer.start()
    }
}
