// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import "pages/elements"

Page {

    // header
    Rectangle {
        id: vkLoginHeader
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
        }

        height: 70
        gradient: Gradient {
            GradientStop {
                position: 0.00;
                color: "#42668C";
            }
            GradientStop {
                position: 1.00;
                color: "#5B7FA6";
            }
        }

        Label {
            id: vkLabel
            anchors {
                verticalCenter: parent.verticalCenter
                horizontalCenter: parent.horizontalCenter
            }
            text: "Учетная запись ВКонтакте"
            color: "#E8EFF7"
        }
        BusyIndicator {
            id: loadingIndicator
            anchors {
                verticalCenter: vkLabel.verticalCenter
                right: vkLabel.left
                rightMargin: 20
            }
            visible: vkLoginService.isLoading
            running: vkLoginService.isLoading
        }
    }

    Item {
        id: loginSubPage
        visible: !settingsSubPage.visible
        anchors {
            left: parent.left
            right: parent.right
            top: vkLoginHeader.bottom
            bottom: parent.bottom
        }

        // login info
        TextField {
            id: fieldLogin

            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
                leftMargin: 20
                rightMargin: 20
                topMargin: 30
            }

            enabled: !vkLoginService.isLoading
            readOnly: vkLoginService.isLoading
            inputMethodHints: Qt.ImhNoAutoUppercase|Qt.ImhNoPredictiveText|Qt.ImhEmailCharactersOnly
            maximumLength: 200
            placeholderText: "Введите e-mail или Логин"

            // easy navigate
            platformSipAttributes: SipAttributes {
                actionKeyLabel: "Далее"
                actionKeyEnabled: fieldLogin.text.length !== 0
            }
            Keys.onReturnPressed: {
                if (fieldLogin.text.length !== 0) {
                    fieldPass.forceActiveFocus();
                }
            }
        }
        TextField {
            id: fieldPass

            anchors {
                left: parent.left
                right: parent.right
                top: fieldLogin.bottom
                leftMargin: 20
                rightMargin: 20
                topMargin: 20
            }

            enabled: !vkLoginService.isLoading
            readOnly: vkLoginService.isLoading
            echoMode: TextInput.Password
            inputMethodHints: Qt.ImhNoAutoUppercase|Qt.ImhNoPredictiveText
            maximumLength: 200
            placeholderText: "Введите Пароль"

            // easy navigate
            platformSipAttributes: SipAttributes {
                actionKeyLabel: vkLoginService.isNeedCaptcha ? "Далее" : "Войти"
                actionKeyEnabled: fieldPass.text.length !== 0
            }
            Keys.onReturnPressed: {
                if (vkLoginService.isNeedCaptcha && fieldPass.text.length !== 0) {
                    fieldCaptcha.forceActiveFocus()
                } else if (loginButton.enabled) {
                    platformCloseSoftwareInputPanel()
                    vkLoginService.processLogin(fieldLogin.text, fieldPass.text, fieldCaptcha.text)
                }
            }
        }

        Rectangle {
            id: captchaBlock
            visible: vkLoginService.isNeedCaptcha
            anchors {
                left: parent.left
                right: parent.right
                top: fieldPass.bottom
                leftMargin: 10
                rightMargin: 10
                topMargin: 20
            }
            color: "transparent"
            height: captchaImgBack.height +
                    captchaImgBack.anchors.topMargin +
                    fieldCaptcha.height +
                    fieldCaptcha.anchors.topMargin +
                    fieldCaptcha.anchors.bottomMargin
            border.color: "red"
            border.width: 2

            Rectangle {
                id: captchaImgBack
                anchors {
                    horizontalCenter: parent.horizontalCenter
                    top: parent.top
                    topMargin: 20
                }
                width: captchaImg.status === Image.Ready ? captchaImg.width : 130
                height: captchaImg.status === Image.Ready ? captchaImg.height : 50
                color: "darkgrey"

                Image {
                    id: captchaImg
                    anchors {
                        verticalCenter: parent.verticalCenter
                        horizontalCenter: parent.horizontalCenter
                    }
                    asynchronous: true
                    cache: false
                    source: vkLoginService.captchaUrl
                }

                BusyIndicator {
                    id: captchaImgIndicator
                    anchors {
                        verticalCenter: parent.verticalCenter
                        horizontalCenter: parent.horizontalCenter
                    }
                    visible: captchaImg.status !== Image.Ready
                    running: captchaImg.status !== Image.Ready
                }
            }

            TextField {
                id: fieldCaptcha

                anchors {
                    left: parent.left
                    right: parent.right
                    top: captchaImgBack.bottom
                    leftMargin: 10
                    rightMargin: 10
                    topMargin: 20
                    bottomMargin: 20
                }

                enabled: !vkLoginService.isLoading
                readOnly: vkLoginService.isLoading
                inputMethodHints: Qt.ImhNoAutoUppercase|Qt.ImhNoPredictiveText
                maximumLength: 20
                placeholderText: "Введите код с картинки"

                // easy navigate
                platformSipAttributes: SipAttributes {
                    actionKeyLabel: "Войти"
                    actionKeyEnabled: loginButton.enabled
                }
                Keys.onReturnPressed: {
                    if (loginButton.enabled) {
                        platformCloseSoftwareInputPanel()
                        vkLoginService.processLogin(fieldLogin.text, fieldPass.text, fieldCaptcha.text)
                    }
                }
            }
        }

        Label {
            id: statusText
            visible: vkLoginService.statusString.length !== 0

            anchors {
                left: parent.left
                right: parent.right
                leftMargin: 20
                rightMargin: 20
                bottom: loginButton.top
                bottomMargin: 15
            }
            textFormat: Text.RichText

            text: vkLoginService.statusString
            color: vkLoginService.isStatusError ? "red" : "black"
        }

        // login button
        Button {
            id: loginButton
            text: "Войти"
            anchors {
                bottom: parent.bottom
                bottomMargin: 10
                horizontalCenter: parent.horizontalCenter
            }

            enabled: !vkLoginService.isLoading &&
                     (fieldLogin.text.length !== 0) &&
                     (fieldPass.text.length !== 0) &&
                     (!vkLoginService.isNeedCaptcha || fieldCaptcha.text.length !== 0)

            onClicked: {
                vkLoginService.processLogin(fieldLogin.text, fieldPass.text, fieldCaptcha.text)
            }
        }
    }

    // settings
    Item {
        id: settingsSubPage
        visible: vkLoginService.settingsList.length !== 0
        anchors {
            left: parent.left
            right: parent.right
            top: vkLoginHeader.bottom
            bottom: parent.bottom
        }

        Label {
            id: settingsHeader

            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
                leftMargin: 20
                rightMargin: 20
                topMargin: 20
            }

            horizontalAlignment: Text.AlignHCenter

            text: "Для продолжения работы с приложением необходимо:"
            font.bold: true
        }

        ListView {
            id: settingsList

            clip: true
            anchors {
                left: parent.left
                right: parent.right
                top: settingsHeader.bottom
                bottom: acceptButton.top
                topMargin: 20
                bottomMargin: 20
            }

            model: vkLoginService.settingsList
            delegate: Item {
                id: settingsItem

                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: 20
                    rightMargin: 20
                }
                height: settingsItemText.height +
                        settingsItemText.anchors.topMargin +
                        settingsItemText.anchors.bottomMargin
                Label {
                    id: settingsItemText
                    anchors {
                        left: parent.left
                        right: parent.right
                        top: parent.top
                        topMargin: 10
                        bottomMargin: 10
                    }
                    text: modelData
                }
                VkCoreListElementDivider {
                    id: settingsDivider

                    anchors.top: parent.top

                    visible: index > 0
                }
            }
        }
        ScrollDecorator {
            flickableItem: settingsList
        }

        // accept button
        Button {
            id: acceptButton
            text: "Разрешить"
            anchors {
                bottom: parent.bottom
                bottomMargin: 10
                horizontalCenter: parent.horizontalCenter
            }

            onClicked: {
                vkLoginService.processAcceptSettings()
            }
        }
    }

    Connections {
        target: vkLoginService
        onIsLoadingChanged: if (!vkLoginService.isLoading) {
                                fieldPass.text = ""
                                fieldCaptcha.text = ""
                                fieldPass.forceActiveFocus()
                            }
    }

    Component.onCompleted: fieldLogin.forceActiveFocus()
}
