// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1
import VkPages 1.0
import "subpages"

Page {
    property bool needDisableToolbar: false

    // services
    VkPageAudioService {
        id: vkPageAudioService
        onAudioAdded: {
            bannerAudioAdded.text = "Добавлена аудиозапись: " + name
            bannerAudioAdded.show();
        }
    }
    VkPageAudioService {
        id: vkOtherUserPageAudioService
    }

    // subpage audio
    property bool isOwnerMode: true
    property bool isAudioPlayerExternal: false
    VkSubpageAudio {
        id: ownerAudioView
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            bottom: audioPlayer.top
        }
        audioService: vkPageAudioService
        audioListModel: searchResultView ? searchResultAudioListModel : accOwnerAudioListModel
        visible: isOwnerMode && !isAudioPlayerExternal
    }

    VkSubpageAudio {
        id: userAudioView
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            bottom: audioPlayer.top
        }
        audioService: vkOtherUserPageAudioService
        audioListModel: searchResultView ? searchResultAudioListModel : (isAudioPlayerExternal ? playlistAudioListModel : someUserAudioListModel)
        visible: !isOwnerMode || isAudioPlayerExternal

        onShowAccountOwnerAudio: {
            isOwnerMode = true
            isAudioPlayerExternal = false
            // enshure ownerId was set
            handleTabActivated()
        }
    }

    // audioplayer
    VkSubpageAudioPlayer {
        id: audioPlayer
        anchors {
            left: parent.left
            right: parent.right
            bottom: parent.bottom
        }

        // always use account owner audioservice for audioplayer, because it is singleton
        audioService: vkPageAudioService
        playlist: playlistAudioListModel

        Connections {
            target: vkPageAudioService
            onBeginUpdateAudioBuffer: audioPlayer.beginUpdateAudioBuffer()
            onEndUpdateAudioBuffer: audioPlayer.endUpdateAudioBuffer(bufferName)
            onAudioListLoaded: audioPlayer.notifyAudioListLoaded(accOwnerAudioListModel)
            onAudioSearchListLoaded: audioPlayer.notifyAudioListLoaded(searchResultAudioListModel)
        }
        Connections {
            target: vkOtherUserPageAudioService
            onAudioListLoaded: audioPlayer.notifyAudioListLoaded(someUserAudioListModel)
            onAudioSearchListLoaded: audioPlayer.notifyAudioListLoaded(searchResultAudioListModel)
        }
    }

    // banners
    InfoBanner{
        id: bannerAudioAdded
        text: ""
        timerEnabled: true
        timerShowTime: 5000
    }

    function showOwnerAudio()
    {
        isOwnerMode = true
        isAudioPlayerExternal = false
    }
    function showOtherUserAudio(uid)
    {
        vkOtherUserPageAudioService.userId = uid
        isOwnerMode = false
        isAudioPlayerExternal = false
    }
    function showExternalAudio(idx, startPlay)
    {
        isAudioPlayerExternal = true
        if (startPlay) {
            audioPlayer.startPlayAudioList(playlistAudioListModel, idx)
        }
    }

    // init
    function handleTabActivated() {
        if (isOwnerMode && !isAudioPlayerExternal) {
            vkPageAudioService.setUserIdFromLogin()
        }
    }
}
