// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import VkPages 1.0
import "subpages"

Page {
    property bool needDisableToolbar: isPhotoViewerActive

    // services
    VkPagePhotosService {
        id: vkPagePhotosService
    }
    VkPagePhotosService {
        id: vkOtherUserPagePhotosService
    }

    // subpage photos
    property bool isOwnerMode: true
    property bool isPhotoViewerActive: false
    property bool isPhotoViewerExternal: false
    VkSubpagePhotos {
        id: ownerPhotosView
        anchors.fill: parent
        photosService: vkPagePhotosService
        albumListModel: accOwnerAlbumListModel
        photoListModel: accOwnerPhotoListModel
        visible: isOwnerMode && !isPhotoViewerActive

        onActivatePhotoViewer: {
            photoViewer.setIndex(photoIdx)
            isPhotoViewerActive = true
        }
    }

    VkSubpagePhotos {
        id: userPhotosView
        anchors.fill: parent
        photosService: vkOtherUserPagePhotosService
        albumListModel: someUserAlbumListModel
        photoListModel: someUserPhotoListModel
        visible: !isOwnerMode && !isPhotoViewerActive

        onShowAccountOwnerPhotos: {
            isOwnerMode = true
            // enshure ownerId was set
            handleTabActivated()
        }
        onActivatePhotoViewer: {
            photoViewer.setIndex(photoIdx)
            isPhotoViewerActive = true
        }
    }

    VkSubpagePhotoView {
        id: photoViewer
        anchors.fill: parent
        photosService: (isOwnerMode || isPhotoViewerExternal) ? vkPagePhotosService : vkOtherUserPagePhotosService
        photoListModel: isPhotoViewerExternal ? externalPhotoListModel :
                                                isOwnerMode ? accOwnerPhotoListModel : someUserPhotoListModel
        visible: isPhotoViewerActive

        onBackToAlbumClicked: {
            if (isPhotoViewerExternal) {
                mainPage.returnToProfileTab()
            }
            isPhotoViewerActive = false
            isPhotoViewerExternal = false
        }
    }

    function showOwnerPhotos()
    {
        ownerPhotosView.showAlbumList()
        isPhotoViewerActive = false
        isOwnerMode = true
    }
    function showOtherUserPhotos(uid)
    {
        userPhotosView.showAlbumList()
        isPhotoViewerActive = false
        vkOtherUserPagePhotosService.userId = uid
        isOwnerMode = false
    }
    function showExternalPhotos(idx)
    {
        isPhotoViewerExternal = true
        photoViewer.setIndex(idx)
        isPhotoViewerActive = true
    }

    // init
    function handleTabActivated() {
        if (isOwnerMode && !isPhotoViewerExternal) {
            vkPagePhotosService.setUserIdFromLogin()
        }
    }
}
