// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import VkPages 1.0
import "subpages"

Page {
    property bool needDisableToolbar: false

    // services
    VkPageProfileService {
        id: vkPageProfileService
    }
    VkPageProfileService {
        id: vkOtherUserPageProfileService
    }

    // subpage user profile
    property bool isOwnerMode: true
    property bool isWallView: false
    property bool isWallViewComments: false
    property bool isFeedView: false
    property bool isFeedViewComments: false
    VkSubpageProfile {
        id: ownerProfilePage
        anchors.fill: parent
        profileService: vkPageProfileService
        isWallMode: isWallView
        visible: !isWallView && !isFeedView && isOwnerMode

        onShowWall: isWallView = true
        onShowFeed: isFeedView = true
    }
    VkSubpageProfile {
        id: otherProfilePage
        anchors.fill: parent
        profileService: vkOtherUserPageProfileService
        isWallMode: isWallView
        visible: !isWallView && !isFeedView && !isOwnerMode

        onShowAccountOwnerPage: isOwnerMode = true
        onShowWall: isWallView = true
    }

    // wall with detailed view and comments
    VkSubpageWall {
        id: wallPage
        anchors.fill: parent
        wallService: isOwnerMode ? vkPageProfileService : vkOtherUserPageProfileService
        isWallMode: isWallView
        wallListModel: isOwnerMode ? accOwnerWallListModel : someUserWallListModel
        senderName: vkPageProfileService.first_name + " " + vkPageProfileService.last_name
        senderAvatar: vkPageProfileService.photo_rec
        visible: isWallView && !isWallViewComments

        onShowAccountOwnerPage: showAccOwnerPage()
        onShowFeed: {
            isFeedView = true
            isWallView = false
        }
        onLeaveWallClicked: isWallView = false
        onViewWallItem: {
            wallItemPage.setWallItemIndex(idx)
            isWallViewComments = true
        }
    }

    VkSubpageWallItemView {
        id: wallItemPage
        anchors.fill: parent
        wallService: isOwnerMode ? vkPageProfileService : vkOtherUserPageProfileService
        wallItemViewerModel: isOwnerMode ? accOwnerWallListModel : someUserWallListModel
        commentListModel: wallCommentsModel
        senderName: vkPageProfileService.first_name + " " + vkPageProfileService.last_name
        senderAvatar: vkPageProfileService.photo_rec
        visible: isWallView && isWallViewComments

        onLeaveFullViewClicked: {
            wallPage.setIndex(idxBack)
            isWallViewComments = false
        }
    }

    // feed with detailed view and comments
    VkSubpageFeed {
        id: feedPage
        anchors.fill: parent
        feedService: vkPageProfileService
        feedListModel: accOwnerFeedListModel
        visible: isFeedView && !isFeedViewComments

        onShowAccountOwnerPage: showAccOwnerPage()
        onViewFeedItem: {
            feedItemPage.setFeedItemIndex(idx)
            isFeedViewComments = true
        }
    }

    VkSubpageFeedItemView {
        id: feedItemPage
        anchors.fill: parent
        feedService: vkPageProfileService
        feedItemViewerModel: accOwnerFeedListModel
        commentListModel: feedCommentsModel
        senderName: vkPageProfileService.first_name + " " + vkPageProfileService.last_name
        senderAvatar: vkPageProfileService.photo_rec
        visible: isFeedView && isFeedViewComments

        onLeaveFullViewClicked: {
            feedPage.setIndex(idxBack)
            isFeedViewComments = false
        }
    }

    function showAccOwnerPage()
    {
        isWallView = false  // disable wall view to prevent loading wall data before actual need it
        isWallViewComments = false
        isFeedView = false  // disable feed view to prevent loading wall data before actual need it
        isFeedViewComments = false
        isOwnerMode = true
    }
    function showOtherUserPage(uid)
    {
        // back-off
        // == instead of === because uid may be string or other type, need type cast
        if (vkPageProfileService.userId == uid) {
            showAccOwnerPage()
            return
        }

        isWallView = false  // disable wall view to prevent loading wall data before actual need it
        isWallViewComments = false
        isFeedView = false  // disable feed view to prevent loading wall data before actual need it
        isFeedViewComments = false
        vkOtherUserPageProfileService.userId = uid
        isOwnerMode = false
    }

    // init
    function handleTabActivated() {
        vkPageProfileService.setUserIdFromLogin()
        vkPageProfileService.autoUpdateEnabled = false
    }
}
