// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1
import VkPages 1.0
import "subpages"

Page {
    property bool needDisableToolbar: false

    // services
    VkPageVideoService {
        id: vkPageVideoService

        onVideoAdded: {
            bannerVideoAdded.text = "Добавлена видеозапись: " + name
            bannerVideoAdded.show();
        }
        onVideoCanAddChanged: videoItemPage.videoCanAddChanged(videoOwnerId, videoItemId, canAddItem)
        onVideoBusyChanged: videoItemPage.videoBusyChanged(videoOwnerId, videoItemId, itemBusy)
        onVideoRemoved: videoItemPage.videoRemoved(idx, videoOwnerId, videoItemId)
        onVideoLikeBusyChanged: videoItemPage.videoLikeBusyChanged(videoOwnerId, videoItemId, itemBusy);
        onVideoLikeInfoChanged: videoItemPage.videoLikeInfoChanged(videoOwnerId, videoItemId, likes_count, likes_user_likes, likes_can_like);
    }
    VkPageVideoService {
        id: vkOtherUserPageVideoService

        onVideoCanAddChanged: videoItemPage.videoCanAddChanged(videoOwnerId, videoItemId, canAddItem)
    }

    // subpage video
    property bool isOwnerMode: true
    property bool isVideoItemView: false
    property bool isVideoPlayerExternal : false
    VkSubpageVideo {
        id: ownerVideoView
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            bottom: parent.bottom
        }
        videoService: vkPageVideoService
        videoListModel: searchResultView ? searchResultVideoListModel : accOwnerVideoListModel
        visible: isOwnerMode && !isVideoItemView

        onShowVideoItem: {
            videoItemPage.setVideoItem(searchResultView ? searchResultVideoListModel : accOwnerVideoListModel, idx, true, searchResultView)
            isVideoItemView = true;
        }
    }

    VkSubpageVideo {
        id: userVideoView
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            bottom: parent.bottom
        }
        videoService: vkOtherUserPageVideoService
        videoListModel: searchResultView ? searchResultVideoListModel : someUserVideoListModel
        visible: !isOwnerMode && !isVideoItemView

        onShowAccountOwnerVideo: {
            isOwnerMode = true
            // enshure ownerId was set
            handleTabActivated()
        }
        onShowVideoItem: {
            videoItemPage.setVideoItem(searchResultView ? searchResultVideoListModel : someUserVideoListModel, idx, false, searchResultView)
            isVideoItemView = true;
        }
    }

    // video item view
    VkSubpageVideoItemView {
        id: videoItemPage
        anchors.fill: parent
        videoService: isOwnerMode ? vkPageVideoService : vkOtherUserPageVideoService
        commentListModel: ListModel { ListElement{name:"Комментарии недоступны в этой версии"} }
        visible: isVideoItemView

        onLeaveFullViewClicked: {
            if (isVideoPlayerExternal) {
                isOwnerMode = true
                isVideoPlayerExternal = false
                // enshure ownerId was set
                handleTabActivated()
            }
            isVideoItemView = false
        }
        onAddVideoItem: {
            if (listModelOwn) {
                vkPageVideoService.markAddedVideoItem(idx, videoOwnerId, videoItemId, fromSearch)
            } else {
                vkOtherUserPageVideoService.markAddedVideoItem(idx, videoOwnerId, videoItemId, fromSearch)
            }
            vkPageVideoService.addVideoItem(videoOwnerId, videoItemId)
        }
        onRemoveVideoItem: {
            if (listModelOwn) {
                vkPageVideoService.deleteVideoItem(idx, videoOwnerId, videoItemId)
            }
        }
    }

    // banners
    InfoBanner{
        id: bannerVideoAdded
        text: ""
        timerEnabled: true
        timerShowTime: 5000
    }

    function showOwnerVideo()
    {
        isVideoItemView = false
        isVideoPlayerExternal = false
        isOwnerMode = true
    }
    function showOtherUserVideo(uid)
    {
        isVideoItemView = false
        isVideoPlayerExternal = false
        vkOtherUserPageVideoService.userId = uid
        isOwnerMode = false
    }
    function showExternalVideo(vid, owner_id, title, description, duration, image, player, likes_count, likes_user_likes, likes_can_like, likes_busy, likes_valid)
    {
        isVideoPlayerExternal = true
        videoItemPage.setVideoItemFromData(vid, owner_id, title, description, duration, image, player, likes_count, likes_user_likes, likes_can_like, likes_busy, likes_valid)
        isVideoItemView = true
    }

    // init
    function handleTabActivated() {
        if (isOwnerMode && !isVideoPlayerExternal) {
            vkPageVideoService.setUserIdFromLogin()
        }
    }
}
