// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: vkAudioListItem

    // signals
    signal itemClicked()
    signal itemContextMenu()

    // internal
    property int verticalMargin: 3
    property bool firstInSection: vkAudioListItem.ListView.section !== vkAudioListItem.ListView.previousSection
    property bool specialState: itemRemoved || addRemoveInProgress

    anchors {
        left: parent ? parent.left : undefined
        right: parent ? parent.right : undefined
    }

    height: elementDivider.height + audioItemBlock.height + verticalMargin * 2

    VkCoreListElementDivider {
        id: elementDivider
        anchors {
            top: parent.top
            topMargin: verticalMargin
        }
        visible: !firstInSection && index > 0
    }

    Item {
        id: audioItemBlock
        visible: !vkAudioListItem.specialState
        anchors {
            left: parent.left
            right: parent.right
            top: elementDivider.bottom
            topMargin: verticalMargin
        }
        height: textInfoBlock.height

        VkCoreText {
            id: textInfoBlock
            anchors {
                left: parent.left
                right: audioInfoBlock.left
            }
            text: "<font color=\"#45688E\"><b>" + artist + "</font></b><br>" + title
            font.pixelSize: 20
        }

        Column {
            id: audioInfoBlock
            anchors {
                right: parent.right
                top: parent.top
            }
            width: 60

            VkCoreText {
                id: audioTime
                anchors {
                    right: parent.right
                }
                text: vkAppService.getTimeFromMSec(duration * 1000)
                font.pixelSize: 14
                font.bold: true
                color: "#45688E"
                wrapMode: Text.NoWrap
            }

            // adiitional info
            Loader {
                id: audioState
                anchors {
                    right: parent.right
                }

                property bool isCurrentAudio: aid === audioPlayer.vk_aid && owner_id === audioPlayer.vk_owner_id
                property bool isLoading:      model.state === 1
                property bool isLoaded:       model.state === 3
                property bool isLoadFailed:   model.state === 2
                property bool isStatePaused:  isCurrentAudio && isLoaded && !audioPlayer.playing
                property bool needExtraInfo:  isLoading || isLoaded || isLoadFailed || isStatePaused

                source: needExtraInfo ? "VkAudioListItemInfo.qml" : ""
            }
        }
    }

    VkCoreSelectionArea {
        anchors {
            fill: audioItemBlock
            leftMargin: -parent.anchors.leftMargin
            rightMargin: -parent.anchors.rightMargin
        }
        allowPressAndhold: true
        onClicked: itemClicked()
        onPressAndHold: itemContextMenu()
        visible: !vkAudioListItem.specialState
    }

    // special states
    Loader {
        anchors.fill: audioItemBlock
        source: vkAudioListItem.specialState ? "VkAudioListItemExtra.qml" : ""
    }
}
