// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: vkCoreAreaSwitcher
    clip: true

    property int area1LabelHeight: 50
    property int area2LabelHeight: 50
    property alias area1LabelText: label1Text.text
    property alias area2LabelText: label2Text.text
    property int changeDuration:   600
    property real labelOpacity:    1
    property color labelColor:     "#42668C"
    property color labelTextColor: "#E8EFF7"

    // functions and signals
    function resetAreaState()
    {
        // back-off
        if (areaSwitcherContent.state === "area1") {
            return;
        }

        areaSwitcherContent.state = "prereset"
        areaSwitcherContent.state = "area1"
    }

    Item {
        id: areaSwitcherContent
        width: parent.width
        height: parent.height * 2 - vkCoreAreaSwitcher.area1LabelHeight - vkCoreAreaSwitcher.area2LabelHeight

        states: [
            State {
                name: "area1"
                PropertyChanges {target: areaSwitcherContent; y: 0}
                PropertyChanges {target: area1Enabler; enabled: false}
                PropertyChanges {target: area2Enabler; enabled: true}
                PropertyChanges {target: area1Label; opacity: 0}
                PropertyChanges {target: area2Label; opacity: vkCoreAreaSwitcher.labelOpacity}
            },
            State {
                name: "area2"
                PropertyChanges {target: areaSwitcherContent; y: -area1.height + vkCoreAreaSwitcher.area1LabelHeight}
                PropertyChanges {target: area1Enabler; enabled: true}
                PropertyChanges {target: area2Enabler; enabled: false}
                PropertyChanges {target: area1Label; opacity: vkCoreAreaSwitcher.labelOpacity}
                PropertyChanges {target: area2Label; opacity: 0}
            }
        ]
        state: "area1"
        transitions: [
            Transition {
                from: "area1,area2"; to: "area1,area2"
                NumberAnimation {properties: "y,opacity"; duration: vkCoreAreaSwitcher.changeDuration; easing.type: Easing.OutQuad}
            }
        ]

        Item {
            id: area1
            anchors {
                top: parent.top
                left: parent.left
            }
            width: vkCoreAreaSwitcher.width
            height: vkCoreAreaSwitcher.height - vkCoreAreaSwitcher.area2LabelHeight
            Item {
                id: area1Placeholder
                anchors.fill: parent

                property bool isAreaActive: areaSwitcherContent.state === "area1"
            }
            Rectangle {
                id: area1Label
                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                }
                height: vkCoreAreaSwitcher.area1LabelHeight
                color: vkCoreAreaSwitcher.labelColor
                opacity: vkCoreAreaSwitcher.labelOpacity

                Label {
                    id: label1Text
                    anchors {
                        verticalCenter: parent.verticalCenter
                        horizontalCenter: parent.horizontalCenter
                    }
                    text: ""
                    color: vkCoreAreaSwitcher.labelTextColor
                }
            }
            MouseArea {
                id: area1Enabler
                anchors.fill: parent
                onClicked: areaSwitcherContent.state = "area1"
            }
        }
        Item {
            id: area2
            anchors {
                top: area1.bottom
                left: parent.left
            }
            width: vkCoreAreaSwitcher.width
            height: vkCoreAreaSwitcher.height - vkCoreAreaSwitcher.area1LabelHeight
            Item {
                id: area2Placeholder
                anchors.fill: parent

                property bool isAreaActive: areaSwitcherContent.state === "area2"
            }
            Rectangle {
                id: area2Label
                anchors {
                    left: parent.left
                    right: parent.right
                    top: parent.top
                }
                height: vkCoreAreaSwitcher.area2LabelHeight
                color: vkCoreAreaSwitcher.labelColor
                opacity: 0

                Label {
                    id: label2Text
                    anchors {
                        verticalCenter: parent.verticalCenter
                        horizontalCenter: parent.horizontalCenter
                    }
                    text: ""
                    color: vkCoreAreaSwitcher.labelTextColor
                }
            }
            MouseArea {
                id: area2Enabler
                anchors.fill: parent
                onClicked: areaSwitcherContent.state = "area2"
            }
        }
    }
    Component.onCompleted: {
        var usedArea = 0;
        for (var i = 0; i < children.length; ++i) {
            if (children[i] !== areaSwitcherContent) {
                if (usedArea === 0) {
                    children[i].clip = true
                    children[i].parent = area1Placeholder
                    --i;
                } else if (usedArea === 1) {
                    children[i].clip = true
                    children[i].parent = area2Placeholder
                    --i;
                } else {
                    break;
                }
                usedArea++;
            }
        }
    }
}
