// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: vkCoreAttachments
    anchors {
        left: parent.left
        right: parent.right
        top: parent.top
    }
    height: loaders.height

    // signals
    signal itemPhotoClicked(int itemIdx, int photoIdx, int pid, string owner_id)    // fix negative int id
    signal itemVideoClicked(int vid, string owner_id, string title, string description, int duration, string image, string player, int v_likes_count, bool v_likes_user_likes, bool v_likes_can_like, bool v_likes_busy, bool v_likes_valid)    // fix negative int id
    signal itemAudioClicked(int itemIdx, int audioIdx, int aid, string owner_id)    // fix negative int id
    signal itemGraffitiClicked(int itemIdx, int graffitiIdx, int gid, string owner_id)  // fix negative int id

    // loaders:
    BusyIndicator {
        anchors.centerIn: loaders
        running: att_busy
        visible: att_busy
    }
    Column {
        id: loaders
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
        }
        visible: !att_busy
        spacing: 5

        // photo
        Loader {
            id: photoListLoader
            anchors {
                left: parent.left
                right: parent.right
            }
            sourceComponent: havePhoto ? photoListComponent : undefined
            onLoaded: { item.listModel = attPhotoModel; item.itemIndex = index }
        }
        // video
        Loader {
            id: videoListLoader
            anchors {
                left: parent.left
                right: parent.right
            }
            sourceComponent: haveVideo ? videoListComponent : undefined
            onLoaded: { item.listModel = attVideoModel; item.itemIndex = index }
        }
        // audio
        Loader {
            id: audioListLoader
            anchors {
                left: parent.left
                right: parent.right
            }
            sourceComponent: haveAudio ? audioListComponent : undefined
            onLoaded: { item.listModel = attAudioModel; item.itemIndex = index }
        }
        // graffiti
        Loader {
            id: graffitiListLoader
            anchors {
                left: parent.left
                right: parent.right
            }
            sourceComponent: haveGraffiti ? graffitiListComponent : undefined
            onLoaded: { item.listModel = attGraffitiModel; item.itemIndex = index }
        }
        // link
        Loader {
            id: linkListLoader
            anchors {
                left: parent.left
                right: parent.right
            }
            sourceComponent: haveLink ? linkListComponent : undefined
            onLoaded: item.listModel = attLinkModel
        }
    }

    // components:
    // photo
    Component {
        id: photoListComponent
        Item {
            property alias listModel: photoListRepeater.model
            property int   itemIndex
            clip: true
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }
            height: photoFlow.height
            Behavior on height {
                 NumberAnimation { duration: 250 }
            }
            Flow {
                id: photoFlow
                anchors {
                    left: parent.left
                    right: parent.right
                    top: parent.top
                }

                spacing: 5

                Repeater {
                    id: photoListRepeater
                    delegate: VkCoreImage {
                        imgSrc:    model.modelData.src
                        imgLoader: "photo"

                        VkCoreSelectionArea {
                            anchors.fill: parent
                            visible: !isBriefView
                            onClicked: itemPhotoClicked(itemIndex, index, model.modelData.pid, model.modelData.owner_id)
                        }
                    }
                }
            }
        }
    }

    // video
    Component {
        id: videoListComponent
        Item {
            property alias listModel: videoListRepeater.model
            property int   itemIndex
            clip: true
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }
            height: videoFlow.height
            Behavior on height {
                 NumberAnimation { duration: 250 }
            }
            Flow {
                id: videoFlow
                anchors {
                    left: parent.left
                    right: parent.right
                    top: parent.top
                }

                spacing: 5

                Repeater {
                    id: videoListRepeater
                    delegate: VkCoreImage {
                        id: videoItem
                        imgSrc:    model.modelData.image
                        imgLoader: "photo"

                        Image {
                            id: videoItemPic
                            anchors.centerIn: parent
                            source: "../../icons/vk-videoclip.png"
                            visible: videoItem.loaded
                        }

                        Rectangle {
                            id: videoInfoBar
                            anchors {
                                left: parent.left
                                right: parent.right
                                bottom: parent.bottom
                            }
                            height: videoInfoTitle.height
                            color: "#A0000000"

                            VkCoreText {
                                id: videoInfoTitle
                                anchors {
                                    left: parent.left
                                    right: videoInfoTime.left
                                    bottom: parent.bottom
                                    leftMargin: 5
                                    rightMargin: 5
                                }
                                text: model.modelData.title
                                font.pixelSize: 14
                                color: "white"
                                textFormat: Text.PlainText
                                elide: Text.ElideRight
                                wrapMode: Text.NoWrap
                            }
                            VkCoreText {
                                id: videoInfoTime
                                anchors {
                                    right: parent.right
                                    bottom: parent.bottom
                                    rightMargin: 5
                                }
                                text: vkAppService.getTimeFromMSec(model.modelData.duration * 1000)
                                font.pixelSize: 14
                                color: "white"
                                wrapMode: Text.NoWrap
                            }
                        }
                        VkCoreSelectionArea {
                            anchors.fill: parent
                            visible: !isBriefView
                            onClicked: itemVideoClicked(model.modelData.vid,
                                                        model.modelData.owner_id,
                                                        model.modelData.title,
                                                        model.modelData.description,
                                                        model.modelData.duration,
                                                        model.modelData.image,
                                                        model.modelData.player,
                                                        model.modelData.likes_count,
                                                        model.modelData.likes_user_likes,
                                                        model.modelData.likes_can_like,
                                                        model.modelData.likes_busy,
                                                        model.modelData.likes_valid
                                                        )
                        }
                    }
                }
            }
        }
    }

    // audio
    Component {
        id: audioListComponent
        Item {
            property alias listModel: audioListRepeater.model
            property int   itemIndex
            clip: true
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }
            height: audioFlow.height
            Behavior on height {
                 NumberAnimation { duration: 250 }
            }
            Flow {
                id: audioFlow
                anchors {
                    left: parent.left
                    right: parent.right
                    top: parent.top
                }

                spacing: 5

                Repeater {
                    id: audioListRepeater
                    delegate: Item {
                        id: audioItem
                        width: audioFlow.width
                        height: textArtist.height + textTitle.height

                        VkCoreText {
                            id: textArtist
                            anchors {
                                left: parent.left
                                right: audioTime.left
                                top: parent.top
                            }
                            text: model.modelData.artist
                            font.pixelSize: 20
                            font.bold: true
                            color: "#45688E"
                        }
                        VkCoreText {
                            id: textTitle
                            anchors {
                                left: parent.left
                                right: audioTime.left
                                top: textArtist.bottom
                            }
                            text: model.modelData.title
                            font.pixelSize: 18
                        }
                        VkCoreText {
                            id: audioTime
                            anchors {
                                right: parent.right
                                verticalCenter: parent.verticalCenter
                            }
                            text: vkAppService.getTimeFromMSec(model.modelData.duration * 1000)
                            font.pixelSize: 14
                            font.bold: true
                            color: "#45688E"
                            wrapMode: Text.NoWrap
                        }

                        VkCoreSelectionArea {
                            anchors.fill: parent
                            visible: !isBriefView
                            onClicked: itemAudioClicked(itemIndex, index, model.modelData.aid, model.modelData.owner_id)
                        }
                    }
                }
            }
        }
    }

    // graffiti
    Component {
        id: graffitiListComponent
        Item {
            property alias listModel: graffitiListRepeater.model
            property int   itemIndex
            clip: true
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }
            height: graffitiFlow.height
            Behavior on height {
                 NumberAnimation { duration: 250 }
            }
            Flow {
                id: graffitiFlow
                anchors {
                    left: parent.left
                    right: parent.right
                    top: parent.top
                }

                spacing: 5

                Repeater {
                    id: graffitiListRepeater
                    delegate: VkCoreImage {
                        id: graffitiItem
                        imgSrc:    model.modelData.src
                        imgLoader: "photo"

                        VkCoreSelectionArea {
                            anchors.fill: parent
                            visible: !isBriefView
                            onClicked: itemGraffitiClicked(itemIndex, index, model.modelData.gid, model.modelData.owner_id)
                        }
                    }
                }
            }
        }
    }

    // link
    Component {
        id: linkListComponent
        Item {
            property alias listModel: linkListRepeater.model
            clip: true
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }
            height: linkFlow.height
            Behavior on height {
                 NumberAnimation { duration: 250 }
            }
            Flow {
                id: linkFlow
                anchors {
                    left: parent.left
                    right: parent.right
                    top: parent.top
                }

                spacing: 5

                Repeater {
                    id: linkListRepeater
                    delegate: Item {
                        id: linkItem
                        width: linkFlow.width
                        height: linkImageTitle.height + linkDesc.height
                        Item {
                            id: linkImageTitle
                            anchors {
                                left: parent.left
                                right: parent.right
                                top: parent.top
                            }
                            height: linkImage.visible ? Math.max(linkImage.height, linkTitle.height) : linkTitle.height
                            VkCoreImage {
                                id: linkImage
                                anchors {
                                    left: parent.left
                                    top: parent.top
                                }
                                imgSrc: model.modelData.image_src
                                imgLoader: "photo"
                                visible: model.modelData.image_src !== ""
                            }
                            VkCoreText {
                                id: linkTitle
                                anchors {
                                    left: linkImage.visible ? linkImage.right : parent.left
                                    right: parent.right
                                    top: parent.top
                                    leftMargin: linkImage.visible ? 5 : 0
                                }
                                text: model.modelData.title
                                font.pixelSize: 20
                                font.bold: true
                                color: "#45688E"
                            }
                            VkCoreSelectionArea {
                                anchors.fill: parent
                                visible: !isBriefView
                                onClicked: Qt.openUrlExternally(model.modelData.url)
                            }
                        }
                        VkCoreText {
                            id: linkDesc
                            anchors {
                                left: parent.left
                                right: parent.right
                                top: linkImageTitle.bottom
                            }
                            text: model.modelData.description
                            font.pixelSize: 18
                        }
                    }
                }
            }
        }
    }
}
