// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0

//TODO: use SwitchStyle instead of VkCoreImageSwitch
//Switch {
//    id: myswitch
//    property url name_checked: checked ? "../../icons/vk-icon-msg-dialogs.png" : "../../icons/vk-icon-msg-lists.png"
//    platformStyle: SwitchStyle {
//        thumb: myswitch.name_checked
//        thumbPressed: myswitch.name_checked
//        thumbDisabled: myswitch.name_checked
//    }
//}
Item {
    id: vkCoreImageSwitch

    property bool checked: false
    property Style platformStyle: SwitchStyle {}
    property alias switchImage: switchImageItem.source

    width: slider.width
    height: slider.height

    Item {
        id: slider

        width: 66
        height: 42

        state: vkCoreImageSwitch.checked ? "checked" : "unchecked"

        property real knobPos: (knob.x - platformStyle.minKnobX) / (platformStyle.maxKnobX - platformStyle.minKnobX)

        Image {
            source: platformStyle.switchOn
            opacity: slider.knobPos
        }
        Image {
            source: platformStyle.switchOff
            opacity: 1.0 - slider.knobPos
        }

        states: [
            State {
                name: "unchecked"
                PropertyChanges { target: knob; x: platformStyle.minKnobX }
            },
            State {
                name: "checked"
                PropertyChanges { target: knob; x: platformStyle.maxKnobX }
            }
        ]

        transitions: [
            Transition {
                SmoothedAnimation { properties: "x"; velocity: 500; maximumEasingTime: 0 }
            }
        ]

        Image {
            id: knob

            Image {
                width: 30
                height: 30
                x: 2
                y: 2
                source: (slider.enabled ? (mouseArea.pressed ? platformStyle.thumbPressed : platformStyle.thumb) : platformStyle.thumbDisabled)

                Image {
                    id: switchImageItem
                    anchors.centerIn: parent
                }
            }

            source: platformStyle.shadow

            y: 4

            width: 34
            height: 34
        }

        MouseArea {
            id: mouseArea
            property int downMouseX
            property int downKnobX
            anchors {
                fill: parent
                rightMargin: platformStyle.mouseMarginRight
                leftMargin: platformStyle.mouseMarginLeft
                topMargin: platformStyle.mouseMarginTop
                bottomMargin: platformStyle.mouseMarginBottom
            }

            function snap() {
                if (knob.x < (platformStyle.maxKnobX + platformStyle.minKnobX) / 2) {
                    if (vkCoreImageSwitch.checked) {
                        vkCoreImageSwitch.checked = false;
                    } else {
                        knob.x = platformStyle.minKnobX;
                    }
                } else {
                    if (!vkCoreImageSwitch.checked) {
                        vkCoreImageSwitch.checked = true;
                    } else {
                        knob.x = platformStyle.maxKnobX;
                    }
                }
            }

            onPressed: {
                downMouseX = mouseX;
                downKnobX = knob.x;
            }

            onPositionChanged: {
                var newKnobX = downKnobX - (downMouseX - mouseX);
                knob.x = newKnobX < platformStyle.minKnobX ? platformStyle.minKnobX : newKnobX > platformStyle.maxKnobX ? platformStyle.maxKnobX : newKnobX;
            }

            onReleased: {
                if (Math.abs(downMouseX - mouseX) < 5)
                    vkCoreImageSwitch.checked = !vkCoreImageSwitch.checked;
                else
                    snap();
            }

            onCanceled: {
                snap();
            }
        }
    }
}
