// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: vkCoreListFooter

    signal moreClicked()

    property bool needInitialLoad: false
    property bool isLoading: false
    property bool showDivider: true

    // internal
    property bool btnMoreClicked: false

    anchors {
        left: parent ? parent.left : undefined
        right: parent ? parent.right : undefined
    }

    height: visible ? footerDivider.height + Math.max(blockLoading.height, blockMore.height) : 0

    VkCoreListElementDivider {
        id: footerDivider
        anchors.top : parent.top
        visible: showDivider && !needInitialLoad
    }

    // more
    Item {
        id: blockMore
        anchors {
            top: footerDivider.top
            left: parent.left
            right: parent.right
        }
        height: btnMore.height + btnMore.anchors.topMargin + btnMore.anchors.bottomMargin

        Button {
            id: btnMore
            anchors {
                top: parent.top
                horizontalCenter: parent.horizontalCenter
                topMargin: 10
                bottomMargin: 10
            }
            text: "Далее"
            enabled: !btnMoreClicked

            function handleClick()
            {
                btnMoreClicked = true
                moreClicked()
            }
            onClicked: handleClick()
        }
        visible: !isLoading
    }

    // is loading
    Item {
        id: blockLoading
        anchors {
            top: footerDivider.top
            left: parent.left
            right: parent.right
        }
        height: labelLoading.height + labelLoading.anchors.topMargin + labelLoading.anchors.bottomMargin

        Label {
            id: labelLoading
            anchors {
                top: parent.top
                horizontalCenter: parent.horizontalCenter
                topMargin: 10
                bottomMargin: 10
            }
            text: "Загрузка"
        }
        BusyIndicator {
            anchors {
                top: labelLoading.top
                right: labelLoading.left
                rightMargin: 20
            }
            running: isLoading
        }
        visible: isLoading
    }

    function handleInitialLoading()
    {
        if (visible && needInitialLoad && !isLoading) {
            btnMore.handleClick()
        }
    }

    onVisibleChanged: handleInitialLoading()
    onNeedInitialLoadChanged: handleInitialLoading()
    onIsLoadingChanged: btnMoreClicked = false  // allow click again after loading
}
