// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: vkCoreListSearch

    signal searchRequest(string request, bool isGlobal)
    signal resetSearch()

    property variant listElement
    property bool searchPanelOpen: false
    property bool searchBusy: true
    property real openOffset: 35
    property alias placeholderText: searchInput.placeholderText
    property string searchButtonText: "Найти"
    property alias timeAutoHide: timerClose.interval
    property int timeTransition: 800
    property real transitionOvershoot: 2

    // internal
    property bool needShow: listElement.moving && !listElement.flicking && listElement.verticalVelocity <= 0 && listElement.contentY < -openOffset
    property bool needHide: state === "searchPanelOpen" && !searchInput.activeFocus && searchInput.text === ""

    anchors {
        left: parent ? parent.left : undefined
        right: parent ? parent.right : undefined
    }
    clip: true

    onNeedShowChanged: if (needShow) {
                           state = "searchPanelOpen"
                       }

    state: "searchPanelClosed"

    states: [
        State {
            name: "searchPanelOpen"
            PropertyChanges {target: vkCoreListSearch; searchPanelOpen: true}
            PropertyChanges {target: vkCoreListSearch; height: searchVisualItem.height}
            PropertyChanges {target: searchVisualItem; opacity: 1}
            PropertyChanges {target: vkCoreListSearch; visible: true}
        },
        State {
            name: "searchPanelClosed"
            PropertyChanges {target: vkCoreListSearch; searchPanelOpen: false}
            PropertyChanges {target: vkCoreListSearch; height: 0}
            PropertyChanges {target: searchVisualItem; opacity: 0}
            PropertyChanges {target: vkCoreListSearch; visible: false}
        }
    ]
    transitions: [
        Transition {
            to: "searchPanelOpen"
            SequentialAnimation {
                PropertyAnimation {target: vkCoreListSearch; properties: "searchPanelOpen"; duration: 1}
                PropertyAnimation {target: vkCoreListSearch; properties: "visible"; duration: 1}
                ParallelAnimation {
                    PropertyAnimation {target: vkCoreListSearch; properties: "height"; duration: timeTransition; easing.overshoot: transitionOvershoot; easing.type: Easing.OutBack}
                    PropertyAnimation {target: searchVisualItem; properties: "opacity"; duration: timeTransition; easing.type: Easing.Linear}
                }
            }
        },
        Transition {
            to: "searchPanelClosed"
            SequentialAnimation {
                ParallelAnimation {
                    PropertyAnimation {target: vkCoreListSearch; properties: "height"; duration: timeTransition; easing.overshoot: transitionOvershoot; easing.type: Easing.InBack}
                    PropertyAnimation {target: searchVisualItem; properties: "opacity"; duration: timeTransition; easing.type: Easing.Linear}
                }
                PropertyAnimation {target: vkCoreListSearch; properties: "visible"; duration: 1}
                PropertyAnimation {target: vkCoreListSearch; properties: "searchPanelOpen"; duration: 1}
            }
        }
    ]
    Timer {
        id: timerClose
        interval: 5000
        repeat: false
        running: vkCoreListSearch.needHide
        onTriggered: vkCoreListSearch.state = "searchPanelClosed"
    }

    Column {
        id: searchVisualItem
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
        }
        Item {
            anchors {
                left: parent.left
                right: parent.right
            }
            height: Math.max(searchInput.height, searchButton.height)
            TextField {
                id: searchInput
                anchors {
                    left: parent.left;
                    right: searchButton.left
                    verticalCenter: searchButton.verticalCenter
                    rightMargin: 10
                }

                // easy action
                platformSipAttributes: SipAttributes {
                    actionKeyLabel: searchButtonText
                    actionKeyEnabled: searchButton.enabled
                }
                Keys.onReturnPressed: {
                    if (searchButton.enabled) {
                        platformCloseSoftwareInputPanel()
                        vkCoreListSearch.searchRequest(searchInput.text, globalSearchSwitch.checked)
                    }
                }

                placeholderText: "Поиск"
                platformStyle: TextFieldStyle { paddingRight: clearButton.width }
            }
            Image {
                id: clearButton
                anchors.right: searchInput.right
                anchors.verticalCenter: searchInput.verticalCenter
                source: "image://theme/icon-m-input-clear"
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        inputContext.reset();   // reset global property inputContext
                        searchInput.text = "";
                        vkCoreListSearch.resetSearch()
                    }
                }
            }
            Button {
                id: searchButton
                anchors {
                    right: parent.right
                    top: parent.top
                }
                width: height
                enabled: !searchBusy && searchInput.text !== ""
                visible: !searchBusy
                iconSource: enabled ? "../../icons/vk-search.png" : "../../icons/vk-search-disabled.png"
                onClicked: vkCoreListSearch.searchRequest(searchInput.text, globalSearchSwitch.checked)
            }
            BusyIndicator {
                anchors.centerIn: searchButton
                visible: searchBusy
                running: searchBusy
            }
        }
        Item {
            anchors {
                left: parent.left
                right: parent.right
                topMargin: 10
            }
            height: globalSearchSwitch.height
            Label {
                anchors {
                    left: parent.left
                    right: globalSearchSwitch.left
                    rightMargin: 10
                    verticalCenter: globalSearchSwitch.verticalCenter
                }

                text: "Глобальный поиск"
            }
            Switch {
                id: globalSearchSwitch
                anchors {
                    right: parent.right
                    top: parent.top
                }
                checked: true
            }
        }
        Item {
            anchors {
                left: parent.left
                right: parent.right
            }
            height: 10
        }
    }
}
