// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0

Item {

    property int    messageReadTimeout: 1000

    // internal
    property int    borderOffset:       6
    property int    inOutMsgOffset:     20
    property int    contentHeight:      nameDateInfo.height + (val_msgHeader.isRealHeader ? val_msgHeader.height : 0) + val_msgText.height
    property int    elementHeight:      contentHeight + borderOffset
    property string msgAuthor:          outMsg ? "Я" : firstName

    anchors {
        left: parent ? parent.left : undefined
        right: parent ? parent.right : undefined
    }

    height: elementHeight + bubbleRect.extraHeight

    Rectangle {
        id: bubbleRectShadow

        anchors {
            left: bubbleRect.left;
            right: bubbleRect.right;
            top: bubbleRect.top;
            bottom: bubbleRect.bottom;
        }

        color: "transparent"
        border.width: 4
        border.color: outMsg ? "#c1c2c4" : "#b5b6b8"
        radius: bubbleRect.radius
    }
    Rectangle {
        id: bubblePinShadow

        anchors {
            horizontalCenter:       outMsg ? bubbleRect.left : bubbleRect.right;
            horizontalCenterOffset: outMsg ? horizontalOffset : -horizontalOffset;
            verticalCenter:         outMsg ? bubbleRect.bottom : bubbleRect.top;
            verticalCenterOffset:   outMsg ? -verticalOffset : verticalOffset;
        }

        property int pinWidth:          26
        property int pinHeight:         30
        property int horizontalOffset:  23
        property int verticalOffset:    7
        width: pinWidth
        height: pinHeight
        rotation: 60

        color: bubbleRect.color
        border.width: 2
        border.color: outMsg ? "#c1c2c4" : "#b5b6b8"
    }
    Rectangle {
        id: bubbleRect
        property int leftOffset:   10
        property int rightOffset:  10
        property int topOffset:    10
        property int bottomOffset: 10

        property int mrgLeft:      outMsg ? 10 : 35
        property int mrgRight:     outMsg ? 35 : 10
        property int mrgTop:       outMsg ? 10 : 20
        property int mrgBottom:    outMsg ? 20 : 10

        property int extraHeight:  topOffset + bottomOffset + mrgTop + mrgBottom

        color: outMsg ? "#f6f8f8" : "#08a6cc"

        anchors {
            left: parent.left; leftMargin: mrgLeft;
            right: parent.right; rightMargin: mrgRight;
            top: parent.top; topMargin: mrgTop;
            bottom: parent.bottom; bottomMargin: mrgBottom;
        }

        radius: 10
    }

    VkCoreText {
        id: nameDateInfo
        anchors {
            left: bubbleRect.left; leftMargin: bubbleRect.leftOffset;
            right: bubbleRect.right; rightMargin: bubbleRect.rightOffset;
            top: bubbleRect.top; topMargin: bubbleRect.topOffset;
        }
        text: "<b>" + msgAuthor + "</b>, " + vkAppService.dateTimePassedToString(msgDate, vkAppService.curDateTimeUpdated, " в ") + " | " + (isSending ? "отправка" : (readState ? "прочитано" : "не прочитано"))
        color: outMsg ? "#777777" : "#eeeeee"
        font.pixelSize: 18
    }
    VkCoreText {
        id: val_msgHeader
        anchors {
            left: bubbleRect.left; leftMargin: bubbleRect.leftOffset;
            right: bubbleRect.right; rightMargin: bubbleRect.rightOffset;
            bottom: val_msgText.top
        }

        property bool isRealHeader: text.length > 0 && text !== "..."

        text: msgHeader
        color: "#45688E"
        horizontalAlignment: Text.AlignHCenter
        elide: Text.ElideRight
        wrapMode: Text.NoWrap
        textFormat: Text.PlainText
        clip: true
        visible: isRealHeader
    }
    VkCoreText {
        id: val_msgText
        anchors {
            left: bubbleRect.left; leftMargin: bubbleRect.leftOffset;
            right: bubbleRect.right; rightMargin: bubbleRect.rightOffset;
            bottom: bubbleRect.bottom; bottomMargin: bubbleRect.bottomOffset;
        }
        text: msgText
        color: outMsg ? "black" : "white"
    }

    // mark read implementation
    property bool   needMarkMessageRead: false
    property bool   isMarkMsgInProcess:  !outMsg && !readState && needMarkMessageRead && !messageReadSent
    property bool   messageReadSent:     false
    Timer {
        id: timerMarkRead
        interval: messageReadTimeout
        running: false
        repeat: false

        onTriggered: {
            messageReadSent = true
            messagesService.dlgMarkMessageRead(msgId)
        }
    }
    function processMarkRead()
    {
        // back-off
        if (outMsg || readState) {
            return
        }

        if (isMarkMsgInProcess) {
            timerMarkRead.start()
        } else {
            timerMarkRead.stop()
        }
    }
    onIsMarkMsgInProcessChanged: processMarkRead()
    onVisibleChanged: needMarkMessageRead = visible
    Component.onCompleted: needMarkMessageRead = visible
    Component.onDestruction: needMarkMessageRead = false
}
