// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: vkFeedAttachments
    anchors {
        left: parent.left
        right: parent.right
        top: parent.top
    }
    height: loaders.height

    // signals
    signal itemPhotoClicked(int photoIdx, int pid, string owner_id, bool isTag)     // fix negative int id

    // loaders:
    BusyIndicator {
        anchors.centerIn: loaders
        running: feed_busy
        visible: feed_busy
    }
    Column {
        id: loaders
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
        }
        visible: !feed_busy
        spacing: 5

        // photo
        Loader {
            id: photoListLoader
            anchors {
                left: parent.left
                right: parent.right
            }
            sourceComponent: feedPhotosCount > 0 ? photoListComponent : undefined
            onLoaded: {
                item.listModel = feedPhotosModel
                item.listCount = feedPhotosCount
                item.userSex   = source_sex
            }
        }
        // photo_tag
        Loader {
            id: photo_tagListLoader
            anchors {
                left: parent.left
                right: parent.right
            }
            sourceComponent: feedPhoto_tagsCount > 0 ? photo_tagListComponent : undefined
            onLoaded: {
                item.listModel = feedPhoto_tagsModel
                item.listCount = feedPhoto_tagsCount
                item.userSex   = source_sex
            }
        }
        // friend
        Loader {
            id: friendListLoader
            anchors {
                left: parent.left
                right: parent.right
            }
            sourceComponent: feedFriendsCount > 0 ? friendListComponent : undefined
            onLoaded: {
                item.listModel = feedFriendsModel
                item.listCount = feedFriendsCount
                item.userSex   = source_sex
            }
        }
    }

    // components:
    // photo
    Component {
        id: photoListComponent
        Item {
            property alias listModel: photoListRepeater.model
            property alias listCount: photoListCounter.number
            property int   userSex:   0
            clip: true
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }
            height: photoListCounter.height + photoFlow.height + photoFlow.anchors.topMargin
            Behavior on height {
                 NumberAnimation { duration: 250 }
            }
            VkCoreLabeledNumber {
                id: photoListCounter
                anchors {
                    left: parent.left
                    right: parent.right
                    top: parent.top
                }

                prefix: userSex === 0 ? "" :
                                        userSex === 1 ? "добавила " : "добавил "
                label: "фотографий"
                label1: userSex === 0 ? "фотография" : "фотографию"
                label234: "фотографии"
            }
            Flow {
                id: photoFlow
                anchors {
                    left: parent.left
                    right: parent.right
                    top: photoListCounter.bottom
                    topMargin: 10
                }

                spacing: 5

                Repeater {
                    id: photoListRepeater
                    delegate: VkCoreImage {
                        id: photoItem
                        imgSrc:    model.modelData.src
                        imgLoader: "photo"

                        VkCoreSelectionArea {
                            anchors.fill: parent
                            visible: !isBriefView
                            onClicked: itemPhotoClicked(index, model.modelData.pid, model.modelData.owner_id, false)
                        }
                    }
                }
            }
        }
    }
    // photo_tag
    Component {
        id: photo_tagListComponent
        Item {
            property alias listModel: photo_tagListRepeater.model
            property alias listCount: photo_tagListCounter.number
            property int   userSex:   0
            clip: true
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }
            height: photo_tagListCounter.height + photo_tagFlow.height + photo_tagFlow.anchors.topMargin
            Behavior on height {
                 NumberAnimation { duration: 250 }
            }
            VkCoreLabeledNumber {
                id: photo_tagListCounter
                anchors {
                    left: parent.left
                    right: parent.right
                    top: parent.top
                }

                prefix: userSex === 0 ? "отмечено " :
                                        userSex === 1 ? "отмечена на " : "отмечен на "
                label: userSex === 0 ? "фотографий" : "фотографиях"
                label1: userSex === 0 ? "фотография" : "фотографии"
                label234: userSex === 0 ? "фотографии" : "фотографиях"
            }
            Flow {
                id: photo_tagFlow
                anchors {
                    left: parent.left
                    right: parent.right
                    top: photo_tagListCounter.bottom
                    topMargin: 10
                }

                spacing: 5

                Repeater {
                    id: photo_tagListRepeater
                    delegate: VkCoreImage {
                        id: photo_tagItem
                        imgSrc:    model.modelData.src
                        imgLoader: "photo"

                        VkCoreSelectionArea {
                            anchors.fill: parent
                            visible: !isBriefView
                            onClicked: itemPhotoClicked(index, model.modelData.pid, model.modelData.owner_id, true)
                        }
                    }
                }
            }
        }
    }
    // friend
    Component {
        id: friendListComponent
        Item {
            property alias listModel: friendListRepeater.model
            property alias listCount: friendListCounter.number
            property int   userSex:   0
            clip: true
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }
            height: friendListCounter.height + friendFlow.height + friendFlow.anchors.topMargin
            Behavior on height {
                 NumberAnimation { duration: 250 }
            }
            VkCoreLabeledNumber {
                id: friendListCounter
                anchors {
                    left: parent.left
                    right: parent.right
                    top: parent.top
                }

                prefix: userSex === 0 ? "" :
                                        userSex === 1 ? "добавила " : "добавил "
                label: "новых друзей"
                label1: userSex === 0 ? "новый друг" : "нового друга"
                label234: userSex === 0 ? "новых друга" : "новых друга"
            }
            Flow {
                id: friendFlow
                anchors {
                    left: parent.left
                    right: parent.right
                    top: friendListCounter.bottom
                    topMargin: 10
                }

                spacing: 5

                Repeater {
                    id: friendListRepeater
                    delegate: Item {
                        id: friendItem
                        width: friendFlow.width
                        height: Math.max(friendAvatar.height, friendName.height)

                        VkCoreAvatar {
                            id: friendAvatar
                            anchors {
                                left: parent.left
                                top: parent.top
                            }

                            imgSrc: model.modelData.photoURL
                            online: model.modelData.online
                        }
                        VkCoreText {
                            id: friendName
                            anchors {
                                left: friendAvatar.right
                                right: parent.right
                                top: friendAvatar.top
                                leftMargin: 5
                            }

                            font.weight: Font.Bold
                            color: "#45688E"
                            text: model.modelData.firstName + " " + model.modelData.lastName
                        }

                        VkCoreSelectionArea {
                            anchors.fill: parent
                            onClicked: mainPage.showUserPage(model.modelData.uid)
                        }
                    }
                }
            }
        }
    }
}
