// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: vkFeedListItem

    property bool isBriefView: true
    property int  fullViewWidth: 0

    // functions and signals
    signal viewFeedItem(int idx)
    signal feedAttNeedFullInfo(int itemIdx)
    signal feedAttFeedNeedFullInfo(int itemIdx)
    signal feedAttPhotoClicked(int itemIdx, int photoIdx, int pid, string owner_id)     // fix negative int id
    signal feedAttFeedPhotoClicked(int itemIdx, int photoIdx, int pid, string owner_id, bool isTag)     // fix negative int id
    signal feedAttVideoClicked(int vid, string owner_id, string title, string description, int duration, string image, string player, int v_likes_count, bool v_likes_user_likes, bool v_likes_can_like, bool v_likes_busy, bool v_likes_valid)     // fix negative int id
    signal feedAttAudioClicked(int itemIdx, int audioIdx, int aid, string owner_id)     // fix negative int id
    signal feedAttGraffitiClicked(int itemIdx, int graffitiIdx, int gid, string owner_id)       // fix negative int id

    anchors {
        left: isBriefView ? (parent ? parent.left : undefined) : undefined
        right: isBriefView ? (parent ? parent.right : undefined) : undefined
        leftMargin: isBriefView ? 20 : 0
        rightMargin: isBriefView ? 20 : 0
    }
    width : isBriefView ? undefined : fullViewWidth

    //
    property int feedInternalMargin: 10
    height: elementDivider.height + elementDivider.anchors.topMargin +
            sourceAvatar.anchors.topMargin +
            sourceName.height +
            feedItemContainer.height + feedItemContainer.anchors.topMargin +
            feedItemInfo.height

    // divider
    VkCoreListElementDivider {
        id: elementDivider
        anchors {
            top: parent.top
            topMargin: 5
        }
        visible: isBriefView && index > 0
    }

    // common header (source id)
    VkCoreAvatar {
        id: sourceAvatar
        anchors {
            left: parent.left
            top: elementDivider.bottom
            topMargin: feedInternalMargin
        }

        imgSrc: source_avatar
        online: source_online
    }
    VkCoreText {
        id: sourceName
        anchors {
            left: sourceAvatar.right
            right: parent.right
            top: sourceAvatar.top
            leftMargin: feedInternalMargin
        }

        font.weight: Font.Bold
        color: "#45688E"
        text: source_name
    }
    // common content
    Item {
        id: feedItemContainer
        anchors {
            left: sourceName.left
            right: parent.right
            top: sourceName.bottom
            topMargin: feedInternalMargin
        }

        height: feedContentContainer.height + (copyText.visible ? copyText.height + feedInternalMargin : 0) //WTF???? "QML Item: Binding loop detected for property "height"": copyText.height

        VkCoreText {
            id: copyText
            visible: text.length > 0
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }

            text: isBriefView ? vkAppService.truncateText(model.copy_text, 100, "...") : model.copy_text
        }
        Rectangle {
            id: copyMarker
            visible: copyText.visible && copyInfo.visible
            anchors {
                left: parent.left
                top: copyText.bottom
                topMargin: feedInternalMargin
            }

            width: 4
            height: feedContentContainer.height
            color: "#C3D1E0"
        }

        // main feed item content
        Item {
            id: feedContentContainer
            anchors {
                left: copyMarker.visible ? copyMarker.right : parent.left
                right: parent.right
                top: copyMarker.visible ? copyMarker.top : (copyText.visible ? copyText.bottom : parent.top)
                leftMargin: copyMarker.visible ? feedInternalMargin : 0
            }

            height: (copyInfo.visible ? copyInfo.height : 0) + feedContent.height + feedContent.anchors.topMargin

            Item {
                id: copyInfo
                anchors {
                    left: parent.left
                    right: parent.right
                    top: parent.top
                }

                visible: copy_owner_id !== 0 && copy_owner_id !== source_id
                height: visible ? Math.max(copyAvatar.height, copyName.height) : 0

                VkCoreAvatar {
                    id: copyAvatar
                    anchors {
                        left: parent.left
                        top: parent.top
                    }

                    imgSrc: copy_avatar
                    online: copy_online
                }
                VkCoreText {
                    id: copyName
                    anchors {
                        left: copyAvatar.right
                        right: parent.right
                        top: copyAvatar.top
                        leftMargin: feedInternalMargin
                    }

                    font.weight: Font.Bold
                    color: "#45688E"
                    text: copy_name
                }
            }

            Item {
                id: feedContent
                anchors {
                    left: parent.left
                    right: parent.right
                    top: copyInfo.bottom
                    topMargin: copyInfo.visible ? feedInternalMargin : 0
                }

                height: (feedItemText.visible ? feedItemText.height : 0) +  //WTF???? "QML Item: Binding loop detected for property "height"": feedItemText.height
                        feedItemAttachments.height + feedItemAttachments.anchors.topMargin +
                        feedItemFeedAttachments.height + feedItemFeedAttachments.anchors.topMargin

                // content
                VkCoreText {
                    id: feedItemText
                    anchors {
                        left: parent.left
                        right: parent.right
                        top: parent.top
                    }
                    text: isBriefView ? vkAppService.truncateText(model.text, 100, "...") : model.text
                    visible: text.length > 0
                }
                // attachments
                Loader {
                    id: feedItemAttachments
                    anchors {
                        left: parent.left
                        right: parent.right
                        top: feedItemText.visible ? feedItemText.bottom : parent.top
                        topMargin: feedItemText.visible ? feedInternalMargin : 0
                    }
                    source: haveAttachments ? "../elements/VkCoreAttachments.qml" : ""

                    onLoaded: tryLoadFullAttInfo()
                    onVisibleChanged: tryLoadFullAttInfo()
                    function tryLoadFullAttInfo()
                    {
                        if (isBriefView) {
                            return
                        }
                        if (status !== Loader.Ready) {
                            return
                        }
                        if (!visible) {
                            return
                        }
                        feedAttNeedFullInfo(index)
                    }
                    Connections {
                        target: feedItemAttachments.item
                        onItemPhotoClicked: feedAttPhotoClicked(itemIdx, photoIdx, pid, owner_id)
                        onItemVideoClicked: feedAttVideoClicked(vid, owner_id, title, description, duration, image, player, v_likes_count, v_likes_user_likes, v_likes_can_like, v_likes_busy, v_likes_valid)
                        onItemAudioClicked: feedAttAudioClicked(itemIdx, audioIdx, aid, owner_id)
                        onItemGraffitiClicked: feedAttGraffitiClicked(itemIdx, graffitiIdx, gid, owner_id)
                    }
                }
                // feed attachments
                Loader {
                    id: feedItemFeedAttachments
                    anchors {
                        left: parent.left
                        right: parent.right
                        top: feedItemAttachments.bottom
                        topMargin: feedItemAttachments.source != "" ? feedInternalMargin : 0
                    }
                    source: feedPhotosCount > 0 || feedPhoto_tagsCount > 0 || feedFriendsCount > 0 ? "../elements/VkFeedAttachments.qml" : ""

                    onLoaded: tryLoadFullFeedInfo()
                    onVisibleChanged: tryLoadFullFeedInfo()
                    function tryLoadFullFeedInfo()
                    {
                        if (isBriefView) {
                            return
                        }
                        if (status !== Loader.Ready) {
                            return
                        }
                        if (!visible) {
                            return
                        }
                        feedAttFeedNeedFullInfo(index)
                    }
                    Connections {
                        target: feedItemFeedAttachments.item
                        onItemPhotoClicked: feedAttFeedPhotoClicked(index, photoIdx, pid, owner_id, isTag)
                    }
                }
            }
        }

        Item {
            id: feedItemInfo
            anchors {
                left: parent.left
                right: parent.right
                top: feedContentContainer.bottom
                topMargin: feedInternalMargin
            }

            height: anchors.topMargin + Math.max(feedItemInfoTime.height, feedItemInfoLoader.height)

            VkCoreText {
                id: feedItemInfoTime
                anchors {
                    left: parent.left
                    right: feedItemInfoLoader.left
                    verticalCenter: feedItemInfoLoader.verticalCenter
                }
                text: vkAppService.dateTimePassedToString(date, vkAppService.curDateTimeUpdated, " в ", true, 0)
                font.pixelSize: 14
                color: "#999999"
                wrapMode: Text.NoWrap
            }
            Loader {
                id: feedItemInfoLoader
                anchors {
                    right: parent.right
                    top: parent.top
                }

                source: type !== "post" ? "" :
                                          isBriefView ? "VkCoreLikeInfo.qml" : "VkCoreLikeControl.qml"
                onLoaded: {
                    if (!isBriefView) {
                        item.repostClicked.connect(processRepost)
                        item.likeClicked.connect(processLike)
                        item.dislikeClicked.connect(processDislike)
                    }
                }

                property string _source_id: source_id       // fix negative int id
                function processRepost()
                {
                    feedService.feedAddPostLike(index, _source_id, post_id, true)
                }
                function processLike()
                {
                    feedService.feedAddPostLike(index, _source_id, post_id, false)
                }
                function processDislike()
                {
                    feedService.feedDeletePostLike(index, _source_id, post_id)
                }
            }
        }
    }
    VkCoreSelectionArea {
        anchors {
            left: parent.left
            right: parent.right
            top: elementDivider.bottom
            bottom: parent.bottom
            leftMargin: -parent.anchors.leftMargin
            rightMargin: -parent.anchors.rightMargin
            topMargin: 5
        }
        visible: isBriefView

        onClicked: viewFeedItem(index)
    }
}
