// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    // signals
    signal msgItemClicked       (int uid, int mid)

    property bool isValidItem: uid > 0

    // internal
    property int verticalMargin: 6
    property int userInfoHeight: Math.max(val_avatar.height + val_avatar.anchors.topMargin, infoBounds.height + infoBounds.anchors.topMargin)

    anchors {
        left: parent ? parent.left : undefined
        right: parent ? parent.right : undefined
    }

    height: isValidItem ? (elementDivider.height + userInfoHeight + val_msgHeader.height + val_msgText.height + verticalMargin * 2) : 0

    VkCoreListElementDivider {
        id: elementDivider
        anchors {
            top: parent.top
            topMargin: verticalMargin
        }
        visible: index > 1
    }

    Rectangle {
        id: nonReadMarker
        anchors {
            right: parent.left
            top: elementDivider.bottom
            bottom: parent.bottom
            rightMargin: 5
        }
        width: 5
        color: "#1082de"
        visible: !readState
    }

    VkCoreAvatar {
        id: val_avatar
        anchors {
            left: parent.left
            top: elementDivider.top
            topMargin: verticalMargin * 2
        }

        imgSrc: avatar
        online: model.online
    }

    Column {
        id: infoBounds
        anchors {
            left: val_avatar.right
            right: parent.right
            top: elementDivider.top
            leftMargin: 20
            topMargin: verticalMargin
        }
        VkCoreText {
            id: mainInfo
            anchors {
                left: parent.left
                right: parent.right
            }
            text: firstName + " " + lastName
            font.weight: Font.Bold
            color: "#45688E"
            font.pixelSize: 20
        }
        VkCoreText {
            id: dateInfo
            anchors {
                left: parent.left
                right: parent.right
            }
            text: vkAppService.dateTimePassedToString(msgDate, vkAppService.curDateTimeUpdated, " в ", false, 0) + " | " + (readState ? "прочитано" : "не прочитано")
            color: "#777777"
            font.pixelSize: 16
        }
    }

    VkCoreText {
        id: val_msgHeader
        anchors {
            left: parent.left
            right: parent.right
            bottom: val_msgText.top
        }
        text: msgHeader
        color: "#45688E"
        horizontalAlignment: Text.AlignHCenter
        elide: Text.ElideRight
        wrapMode: Text.NoWrap
        textFormat: Text.PlainText
        clip: true
    }
    VkCoreText {
        id: val_msgText
        anchors {
            left: parent.left
            right: parent.right
            bottom: parent.bottom
            bottomMargin: verticalMargin
        }
        text: msgText
        clip: true
    }

    VkCoreSelectionArea {
        anchors {
            left: parent.left
            right: parent.right
            top: elementDivider.bottom
            bottom: parent.bottom
            leftMargin: -parent.anchors.leftMargin
            rightMargin: -parent.anchors.rightMargin
            topMargin: verticalMargin
        }
        onClicked: msgItemClicked(uid, msgId)
        enabled: isValidItem
    }

    visible: isValidItem
}
