// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: vkWallListItem

    property bool isBriefView: true
    property int  fullViewWidth: 0

    // functions and signals
    signal viewWallItem(int idx)
    signal wallAttNeedFullInfo(int itemIdx)
    signal wallAttPhotoClicked(int itemIdx, int photoIdx, int pid, string owner_id)     // fix negative int id
    signal wallAttVideoClicked(int vid, string owner_id, string title, string description, int duration, string image, string player, int v_likes_count, bool v_likes_user_likes, bool v_likes_can_like, bool v_likes_busy, bool v_likes_valid)     // fix negative int id
    signal wallAttAudioClicked(int itemIdx, int audioIdx, int aid, string owner_id)     // fix negative int id
    signal wallAttGraffitiClicked(int itemIdx, int graffitiIdx, int gid, string owner_id)       // fix negative int id

    anchors {
        left: isBriefView ? (parent ? parent.left : undefined) : undefined
        right: isBriefView ? (parent ? parent.right : undefined) : undefined
        leftMargin: isBriefView ? 20 : 0
        rightMargin: isBriefView ? 20 : 0
    }
    width : isBriefView ? undefined : fullViewWidth

    //
    property int wallInternalMargin: 10
    height: elementDivider.height + elementDivider.anchors.topMargin +
            fromAvatar.anchors.topMargin +
            fromName.height +
            wallItemContainer.height + wallItemContainer.anchors.topMargin +
            wallItemInfo.height

    // divider
    VkCoreListElementDivider {
        id: elementDivider
        anchors {
            top: parent.top
            topMargin: 5
        }
        visible: isBriefView && index > 0
    }

    // common header (from id)
    VkCoreAvatar {
        id: fromAvatar
        anchors {
            left: parent.left
            top: elementDivider.bottom
            topMargin: wallInternalMargin
        }

        imgSrc: from_avatar
        online: from_online
    }
    VkCoreText {
        id: fromName
        anchors {
            left: fromAvatar.right
            right: parent.right
            top: fromAvatar.top
            leftMargin: wallInternalMargin
        }

        font.weight: Font.Bold
        color: "#45688E"
        text: from_name
    }
    // common content
    Item {
        id: wallItemContainer
        anchors {
            left: fromName.left
            right: parent.right
            top: fromName.bottom
            topMargin: wallInternalMargin
        }

        height: wallContentContainer.height + (copyText.visible ? copyText.height + wallInternalMargin : 0) //WTF???? "QML Item: Binding loop detected for property "height"": copyText.height

        VkCoreText {
            id: copyText
            visible: text.length > 0
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }

            text: isBriefView ? vkAppService.truncateText(model.copy_text, 100, "...") : model.copy_text
        }
        Rectangle {
            id: copyMarker
            visible: copyText.visible && copyInfo.visible
            anchors {
                left: parent.left
                top: copyText.bottom
                topMargin: wallInternalMargin
            }

            width: 4
            height: wallContentContainer.height
            color: "#C3D1E0"
        }

        // main wall item content
        Item {
            id: wallContentContainer
            anchors {
                left: copyMarker.visible ? copyMarker.right : parent.left
                right: parent.right
                top: copyMarker.visible ? copyMarker.top : (copyText.visible ? copyText.bottom : parent.top)
                leftMargin: copyMarker.visible ? wallInternalMargin : 0
            }

            height: (copyInfo.visible ? copyInfo.height : 0) + wallContent.height + wallContent.anchors.topMargin

            Item {
                id: copyInfo
                anchors {
                    left: parent.left
                    right: parent.right
                    top: parent.top
                }

                visible: copy_owner_id !== 0 && copy_owner_id !== from_id
                height: visible ? Math.max(copyAvatar.height, copyName.height) : 0

                VkCoreAvatar {
                    id: copyAvatar
                    anchors {
                        left: parent.left
                        top: parent.top
                    }

                    imgSrc: copy_avatar
                    online: copy_online
                }
                VkCoreText {
                    id: copyName
                    anchors {
                        left: copyAvatar.right
                        right: parent.right
                        top: copyAvatar.top
                        leftMargin: wallInternalMargin
                    }

                    font.weight: Font.Bold
                    color: "#45688E"
                    text: copy_name
                }
            }

            Item {
                id: wallContent
                anchors {
                    left: parent.left
                    right: parent.right
                    top: copyInfo.bottom
                    topMargin: copyInfo.visible ? wallInternalMargin : 0
                }

                height: (wallItemText.visible ? wallItemText.height : 0) + wallItemAttachments.height + wallItemAttachments.anchors.topMargin

                // content
                VkCoreText {
                    id: wallItemText
                    anchors {
                        left: parent.left
                        right: parent.right
                        top: parent.top
                    }
                    text: isBriefView ? vkAppService.truncateText(model.text, 100, "...") : model.text
                    visible: text.length > 0
                }
                // attachments
                Loader {
                    id: wallItemAttachments
                    anchors {
                        left: parent.left
                        right: parent.right
                        top: wallItemText.visible ? wallItemText.bottom : parent.top
                        topMargin: wallItemText.visible ? wallInternalMargin : 0
                    }
                    source: haveAttachments ? "../elements/VkCoreAttachments.qml" : ""

                    onLoaded: tryLoadFullInfo()
                    onVisibleChanged: tryLoadFullInfo()
                    function tryLoadFullInfo()
                    {
                        if (isBriefView) {
                            return
                        }
                        if (status !== Loader.Ready) {
                            return
                        }
                        if (!visible) {
                            return
                        }
                        wallAttNeedFullInfo(index)
                    }
                    Connections {
                        target: wallItemAttachments.item
                        onItemPhotoClicked: wallAttPhotoClicked(itemIdx, photoIdx, pid, owner_id)
                        onItemVideoClicked: wallAttVideoClicked(vid, owner_id, title, description, duration, image, player, v_likes_count, v_likes_user_likes, v_likes_can_like, v_likes_busy, v_likes_valid)
                        onItemAudioClicked: wallAttAudioClicked(itemIdx, audioIdx, aid, owner_id)
                        onItemGraffitiClicked: wallAttGraffitiClicked(itemIdx, graffitiIdx, gid, owner_id)
                    }
                }
            }
        }
        Item {
            id: wallItemInfo
            anchors {
                left: parent.left
                right: parent.right
                top: wallContentContainer.bottom
                topMargin: wallInternalMargin
            }

            height: anchors.topMargin + Math.max(wallItemInfoTime.height, wallItemInfoLoader.height)

            VkCoreText {
                id: wallItemInfoTime
                anchors {
                    left: parent.left
                    right: wallItemInfoLoader.left
                    verticalCenter: wallItemInfoLoader.verticalCenter
                }
                text: isSending ? "отправка" : vkAppService.dateTimePassedToString(date, vkAppService.curDateTimeUpdated, " в ", true, 0)
                font.pixelSize: 14
                color: "#999999"
                wrapMode: Text.NoWrap
            }
            Loader {
                id: wallItemInfoLoader
                anchors {
                    right: parent.right
                    top: parent.top
                }

                source: isBriefView ? "VkCoreLikeInfo.qml" : "VkCoreLikeControl.qml"
                onLoaded: {
                    if (!isBriefView) {
                        item.repostClicked.connect(processRepost)
                        item.likeClicked.connect(processLike)
                        item.dislikeClicked.connect(processDislike)
                    }
                }

                property string _to_id: to_id       // fix negative int id
                function processRepost()
                {
                    wallService.wallAddLike(index, _to_id, id, true)
                }
                function processLike()
                {
                    wallService.wallAddLike(index, _to_id, id, false)
                }
                function processDislike()
                {
                    wallService.wallDeleteLike(index, _to_id, id)
                }
            }
        }
    }
    VkCoreSelectionArea {
        anchors {
            left: parent.left
            right: parent.right
            top: elementDivider.bottom
            bottom: parent.bottom
            leftMargin: -parent.anchors.leftMargin
            rightMargin: -parent.anchors.rightMargin
            topMargin: 5
        }
        visible: isBriefView

        onClicked: viewWallItem(index)
    }
}
