// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import VkPages 1.0
import "../elements"

VkSubpageBase {
    id: vkSubpageAudio

    property variant audioService
    loadingText: "Загрузка аудиозаписей"
    basePageService: audioService

    property bool searchResultView: false
    property string commonTitle: audioService.isAccountOwner ? "Мои аудиозаписи" : "Аудиозаписи " + (isAudioPlayerExternal ? "" : audioService.audioOwnerFName)

    // signas
    signal showAccountOwnerAudio()

    property alias audioListModel: audioList.model

    Item {
        anchors {
            fill: parent
            leftMargin: 20
            rightMargin: 20
        }
        VkCoreText {
            id: emptyListLabel
            anchors.fill: parent
            anchors.topMargin: searchResultView ? parent.height * 0.25 : 0

            property bool labelEnabled: true

            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text: searchResultView ? "Аудиозаписи не найдены" : "Нет аудиозаписей"
            font.bold: true
            font.pixelSize: 60
            color: "darkgrey"
            visible: (labelEnabled || searchResultView) && audioListModel.count === 0
        }
    }

    // audio list
    Item {
        anchors.fill: parent
        ListView {
            id: audioList
            anchors.fill: parent
            delegate: VkAudioListItem {
                anchors {
                    leftMargin: 20
                    rightMargin: 20
                }

                onItemClicked: audioPlayer.startPlayAudioList(audioListModel, index)
                onItemContextMenu: {
                    audioContextMenu.contextItemIndex = index
                    audioContextMenu.addEnabled       = canAddItem
                    audioContextMenu.delEnabled       = canRemoveItem
                    audioContextMenu.audioOwnerId     = owner_id
                    audioContextMenu.audioItemId      = aid
                    audioContextMenu.isSearchActive   = searchResultView
                    audioContextMenu.open();
                }
            }

            section.property: "searchType"
            section.criteria: ViewSection.FullString
            section.delegate: Column {
                width: parent.width

                VkCoreListElementDivider {
                    anchors {
                        leftMargin: 0
                        rightMargin: 0
                    }
                }
                VkCoreText {
                    anchors {
                        left: parent.left
                        right: parent.right
                        leftMargin: 10
                        rightMargin: 10
                    }
                    text: section === "local" ? commonTitle : "Результаты поиска"
                    font.bold: true
                    font.pixelSize: 32
                }
                VkCoreListElementDivider {
                    anchors {
                        leftMargin: 0
                        rightMargin: 0
                    }
                }
            }

            header: Column {
                anchors {
                    left: parent ? parent.left : undefined
                    right: parent ? parent.right : undefined
                }
                spacing: 10
                VkCorePageHeader {
                    headerLabelText: commonTitle

                    VkCoreAvatar {
                        anchors {
                            right: parent.right
                            verticalCenter: parent.verticalCenter
                            rightMargin: 10
                        }

                        imgSrc: audioService.audioOwnerAvatar
                        online: audioService.audioOwnerOnline

                        VkCoreSelectionArea {
                            anchors.fill: parent
                            onClicked: mainPage.showUserPage(audioService.userId)
                        }

                        visible: !audioService.isAccountOwner && !isAudioPlayerExternal
                    }
                }
                Item {
                    id: buttonPlaceholder
                    // fix header height change artefacts

                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    height: !audioService.isAccountOwner ? btnToOwherAudio.height : 0

                    Button {
                        id: btnToOwherAudio
                        anchors {
                            left: parent.left
                            right: parent.right
                            leftMargin: 20
                            rightMargin: 20
                        }

                        text: "К моим аудиозаписям"
                        visible: !audioService.isAccountOwner
                        onClicked: showAccountOwnerAudio()
                    }
                }
                VkCoreLabeledNumber {
                    anchors {
                        left: parent.left
                        right: parent.right
                        leftMargin: 20
                        rightMargin: 20
                    }

                    number: audioListModel.count
                    label: "аудиозаписей"
                    label1: "аудиозапись"
                    label234: "аудиозаписи"

                    hideZero: true
                }
                VkCoreListElementDivider {
                    anchors {
                        leftMargin: 0
                        rightMargin: 0
                    }
                }
                Item {
                    id: headerDummy
                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    height: 10
                }
                VkCoreListSearch {
                    id: audioSearch
                    anchors {
                        leftMargin: 20
                        rightMargin: 20
                    }

                    listElement: audioList
                    searchBusy: audioService.audioSearchInProcess

                    onSearchRequest: {
                        // start new search here
                        searchResultView = false
                        audioService.searchAudio(request, isGlobal)
                        searchResultView = true
                    }
                    onResetSearch: searchResultView = false
                    Binding {
                        target: emptyListLabel
                        property: "labelEnabled"
                        value: !audioSearch.searchPanelOpen
                    }
                }
            }
        }
        ScrollDecorator {
            flickableItem: audioList
        }
    }

    ContextMenu {
        id: audioContextMenu
        property bool addEnabled: false
        property bool delEnabled: false
        property int  contextItemIndex: -1
        property string audioOwnerId: "0"   // fix negative int id
        property int  audioItemId: -1
        property bool isSearchActive: false
        MenuLayout {
            id: menuLayout
              MenuItem {
                  id: audioPlay
                  text: "Воспроизвести"
                  onClicked: audioPlayer.startPlayAudioList(audioListModel, audioContextMenu.contextItemIndex)
              }
              MenuItem {
                  id: audioAdd
                  enabled: audioContextMenu.addEnabled
                  text: "Добавить"
                  onClicked: {
                      audioService.markAddedAudioItem(audioContextMenu.contextItemIndex, audioContextMenu.audioOwnerId, audioContextMenu.audioItemId, audioContextMenu.isSearchActive)
                      vkPageAudioService.addAudioItem(audioContextMenu.audioOwnerId, audioContextMenu.audioItemId)
                  }
              }
              MenuItem {
                  id: audioDel
                  enabled: audioContextMenu.delEnabled
                  text: "Удалить"
                  onClicked: audioService.deleteAudioItem(audioContextMenu.contextItemIndex, audioContextMenu.audioOwnerId, audioContextMenu.audioItemId)
              }
        }
    }
}
