// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import QtMultimediaKit 1.1
import VkPages 1.0
import "../elements"

Rectangle {
    id: vkSubpageAudioPlayer

    property variant audioService

    property bool   playing:            false
    property bool   buffering:          false
    property int    index:              -1
    property int    vk_aid:             0
    property string vk_owner_id:        "0"     // fix negative int id
    property string currentAudioUrl:    ""
    property string artist:             ""
    property string title:              ""
    property int    knownDuration:      0
    property int    duration:           audio.source != "" ? audio.duration : knownDuration * 1000
    property string durationTime:       vkAppService.getTimeFromMSec(duration)
    property alias  position:           audio.position
    property string positionTime:       audio.source != "" ? vkAppService.getTimeFromMSec(position) : "-:--"
    property bool   seekable:           audio.seekable
    property alias  audioVolume:        audio.volume
    property bool   repeat:             false
    property bool   shuffle:            false
    property string error:              audio.errorString
    property variant playlist
    property bool   isControlsEnabled:  false

    color: "black"
    height: playerUI.height

    // key controls
    focus: true
    Keys.onPressed: {
//        if (event.key === Qt.Key_VolumeUp || event.key === Qt.Key_Up) {
//            sliderVol.value = sliderVol.value + sliderVol.stepSize
//            event.accepted = true;
//        }
//        if (event.key === Qt.Key_VolumeDown || event.key === Qt.Key_Down) {
//            sliderVol.value = sliderVol.value - sliderVol.stepSize
//            event.accepted = true;
//        }
        if (event.key === Qt.Key_MediaPrevious || event.key === Qt.Key_Left) {
            rewindBackward()
            event.accepted = true;
        }
        if (event.key === Qt.Key_MediaNext || event.key === Qt.Key_Right) {
            rewindForward()
            event.accepted = true;
        }
    }
    Keys.onReleased: {
        if (event.key === Qt.Key_MediaPrevious || event.key === Qt.Key_Left) {
            rewindBackwardStop()
            event.accepted = true;
        }
        if (event.key === Qt.Key_MediaNext || event.key === Qt.Key_Right) {
            rewindForwardStop()
            event.accepted = true;
        }
    }

    property int    rewForwardStep:     0
    property int    rewForwardMax:      15000
    property int    rewBackwardStep:    0
    property int    rewBackwardMax:     15000
    property real   rewMultiplier:      1.1
    function rewindForward()
    {
        if (rewForwardStep <= 0) {
            rewForwardStep = sliderPos.stepSize
        } else {
            rewForwardStep = rewForwardStep * rewMultiplier
            if (rewForwardStep > rewForwardMax) {
                rewForwardStep = rewForwardMax
            }
        }
        vkSubpageAudioPlayer.position = vkSubpageAudioPlayer.position + rewForwardStep
    }
    function rewindForwardStop()
    {
        rewForwardStep = 0
    }
    function rewindBackward()
    {
        if (rewBackwardStep <= 0) {
            rewBackwardStep = sliderPos.stepSize
        } else {
            rewBackwardStep = rewBackwardStep * rewMultiplier
            if (rewBackwardStep > rewBackwardMax) {
                rewBackwardStep = rewBackwardMax
            }
        }
        vkSubpageAudioPlayer.position = vkSubpageAudioPlayer.position - rewBackwardStep
    }
    function rewindBackwardStop()
    {
        rewBackwardStep = 0
    }

    // player functions
    function beginUpdateAudioBuffer()
    {
        audio.stop()
        audio.source       = ""
    }

    function endUpdateAudioBuffer(bufferName)
    {
        buffering          = false
        audio.source       = bufferName
        if (playing) {
            audio.play()
        }
    }

    function setCurrent(idx) {
        if (playing) {
            stop()
        }

        index = idx

        // back-off
        if (index < 0 || index >= playlist.count) {
            buffering                       = false
            vk_aid                          = 0
            vk_owner_id                     = 0
            currentAudioUrl                 = ""
            audio.source                    = ""
            audioService.setAudioUrl("", "");
            vkSubpageAudioPlayer.artist        = ""
            vkSubpageAudioPlayer.title         = ""
            vkSubpageAudioPlayer.knownDuration = 0
            return false
        }

        vk_aid                          = playlist.data(index, "aid")
        vk_owner_id                     = playlist.data(index, "owner_id")
        currentAudioUrl                 = playlist.data(index, "url")
        buffering                       = true
        audio.source                    = ""
        audioService.setAudioUrl(currentAudioUrl, playlist.data(index, "altKey"));
        vkSubpageAudioPlayer.artist        = playlist.data(index, "artist")
        vkSubpageAudioPlayer.title         = playlist.data(index, "title")
        vkSubpageAudioPlayer.knownDuration = playlist.data(index, "duration")
        return true
    }

    function play() {
        if (index < 0) {
            if (!next()) {
                return
            }
        }
        if (audio.source != "" && buffering == false) {
            audio.play()
        }
        playing = true
    }

    function pause() {
        audio.pause()
        playing = false
    }

    function stop() {
        audio.stop()
        playing = false
    }

    function previous() {
        var wasPlaying = playing

        var i = shuffle ? (Math.random() * (playlist.count - 1)) : (index - 1)
        var start_i = i;
        while (true) {
            if (i < 0) {
                i = repeat ? (playlist.count - 1) : 0
                if (!repeat) {
                    wasPlaying = false
                }
            }
            if (!playlist.data(i, "itemRemoved") && !playlist.data(i, "addRemoveInProgress")) {
                break;
            }

            // try another
            i -= 1;
            if (i === start_i) {
                // no valid items
                return false
            }
        }

        if (!setCurrent(i)) {
            return false
        }

        if (wasPlaying) {
            play();
        }
        return true
    }

    function next() {
        var wasPlaying = playing

        var i = shuffle ? (Math.random() * (playlist.count - 1)) : (index + 1)
        var start_i = i;
        while (true) {
            if (i > playlist.count - 1) {
                i = repeat ? 0 : playlist.count - 1
                if (!repeat) {
                    wasPlaying = false
                }
            }
            if (!playlist.data(i, "itemRemoved") && !playlist.data(i, "addRemoveInProgress")) {
                break;
            }

            // try another
            i += 1;
            if (i === start_i) {
                // no valid items
                return false
            }
        }

        if (!setCurrent(i)) {
            return false
        }

        if (wasPlaying) {
            play();
        }
        return true
    }

    function notifyAudioListLoaded(audioList) {
        // back-off
        if (playing) {
            return;
        }

        playlist.copyFrom(audioList)
        setCurrent(-1)
        isControlsEnabled = playlist.count > 0
    }

    function startPlayAudioList(audioList, idx) {
        playlist.copyFrom(audioList)
        setCurrent(idx)
        play()
        isControlsEnabled = playlist.count > 0
    }

    // Artist & Title
    Item {
        id: playerUI
        anchors {
            left: parent.left
            right: parent.right
            bottom: parent.bottom
            leftMargin: 10
            rightMargin: 10
        }
        height: textArtist.height + textArtist.anchors.topMargin + textTitle.height + sliders.height + buttons.height
        VkCoreText {
            id: textArtist

            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
                topMargin: 5
            }

            color: "white"
            font.pixelSize: 18
            wrapMode: Text.NoWrap
            text: vkSubpageAudioPlayer.artist

            Behavior on text {
                NumberAnimation {
                    target: textArtist
                    property: "opacity"
                    from: 0
                    to: 1
                    duration: 1000
                }
            }
        }
        BusyIndicator {
            id: loadingIndicator
            anchors {
                left: parent.left
                top: textArtist.bottom
            }
            platformStyle: BusyIndicatorStyle { inverted: true; size: "small" }
            visible: buffering
            running: buffering
        }
        VkCoreText {
            id: textTitle

            anchors {
                left: buffering ? loadingIndicator.right : parent.left
                right: parent.right
                top: textArtist.bottom
            }

            color: "white"
            font.pixelSize: 16
            wrapMode: Text.NoWrap
            text: vkSubpageAudioPlayer.title

            Behavior on text {
                NumberAnimation {
                    target: textTitle
                    property: "anchors.leftMargin"
                    easing.type: Easing.OutBounce
                    from: vkSubpageAudioPlayer.width
                    to: 0
                    duration: 1000
                }
            }
        }

        // Sliders
        Item {
            id: sliders
            anchors {
                left: parent.left
                right: parent.right
                bottom: buttons.top
                leftMargin: -20
                rightMargin: -20
            }
            height: Math.max(positionSlider.height, volumeSlider.height)

            Item {
                id: positionSlider
                anchors {
                    left: parent.left
                    right: volumeSlider.left
                    bottom: parent.bottom
                }
                height: sliderPos.height + positionCurrent.height + timeTextMargin

                property int timeTextMargin: -8

                Slider {
                    id: sliderPos

                    anchors {
                        left: parent.left
                        right: parent.right
                        bottom: parent.bottom
                    }

                    platformStyle: SliderStyle { inverted: true }

                    enabled: vkSubpageAudioPlayer.isControlsEnabled
                    minimumValue: 0
                    maximumValue: vkSubpageAudioPlayer.duration
                    stepSize: 1000
                    valueIndicatorVisible: true
                    valueIndicatorText: vkAppService.getTimeFromMSec(value)

                    onPressedChanged: {
                        if (!pressed) {
                            vkSubpageAudioPlayer.position = value
                        }
                    }

                    Binding {
                        target: sliderPos
                        property: "value"
                        value: vkSubpageAudioPlayer.position
                        when: !sliderPos.pressed
                    }
                }

                Text {
                    id: positionCurrent
                    anchors {
                        left: sliderPos.left
                        bottom: sliderPos.top
                        leftMargin: 20
                        bottomMargin: positionSlider.timeTextMargin
                    }
                    text: vkSubpageAudioPlayer.positionTime
                    font.pixelSize: 14
                    color: "lightblue"
                }
                Text {
                    id: positionMax
                    anchors {
                        right: sliderPos.right
                        bottom: sliderPos.top
                        rightMargin: 20
                        bottomMargin: positionSlider.timeTextMargin
                    }
                    text: vkSubpageAudioPlayer.durationTime
                    font.pixelSize: 14
                    color: "lightblue"
                }
            }

            Item {
                id: volumeSlider

                anchors {
                    right: parent.right
                    bottom: parent.bottom
                }
                width: 180
                height: sliderVol.height

                Slider {
                    id: sliderVol

                    anchors {
                        left: parent.left
                        right: parent.right
                        bottom: parent.bottom
                    }

                    platformStyle: SliderStyle { inverted: true }

                    minimumValue: 0
                    maximumValue: 1
                    value: vkSubpageAudioPlayer.audioVolume
                    stepSize: 0.01
                    valueIndicatorVisible: true
                    valueIndicatorText: Math.floor(value * 100)

                    onValueChanged: {
                        if (pressed) {
                            vkSubpageAudioPlayer.audioVolume = value
                        }
                    }
                    Binding {
                        target: sliderVol
                        property: "value"
                        value: vkSubpageAudioPlayer.audioVolume
                        when: !sliderVol.pressed
                    }
                }
            }
        }

        // Buttons
        Item {
            id: buttons
            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
            }
            height: buttonsRow.height + 12

            Row {
                id: buttonsRow
                height: plrPrev.height
                anchors {
                    left: parent.left
                    right: parent.right
                    top: parent.top
                }
                spacing: (width - plrPrev.width - plrRev.width - plrPlayPause.width - plrFwd.width - plrNext.width) / 4

                Button {
                    id: plrPrev
                    iconSource: "image://theme/icon-m-toolbar-mediacontrol-previous-white"
                    width: height
                    platformStyle: ButtonStyle { inverted: true }
                    enabled: vkSubpageAudioPlayer.isControlsEnabled
                    onClicked: previous()
                }
                Button {
                    id: plrRev
                    iconSource: "image://theme/icon-m-toolbar-mediacontrol-backwards-white"
                    width: height
                    platformStyle: ButtonStyle { inverted: true }
                    enabled: vkSubpageAudioPlayer.isControlsEnabled
                    //platformAutoRepeat: true
                    onClicked: rewindBackward()
                    //onPlatformReleased: rewindBackwardStop()
                }
                Button {
                    id: plrPlayPause
                    property bool isPauseButton: vkSubpageAudioPlayer.playing
                    checkable: true
                    iconSource: isPauseButton ? "image://theme/icon-m-toolbar-mediacontrol-pause-white" : "image://theme/icon-m-toolbar-mediacontrol-play-white"
                    width: height
                    platformStyle: ButtonStyle { inverted: true }
                    enabled: vkSubpageAudioPlayer.isControlsEnabled
                    onClicked: {
                        if (isPauseButton) {
                            pause()
                        } else {
                            play()
                        }
                    }

                    Binding {
                        target: plrPlayPause
                        property: "checked"
                        value: plrPlayPause.isPauseButton
                    }
                }
                Button {
                    id: plrFwd
                    iconSource: "image://theme/icon-m-toolbar-mediacontrol-forward-white"
                    width: height
                    platformStyle: ButtonStyle { inverted: true }
                    enabled: vkSubpageAudioPlayer.isControlsEnabled
                    //platformAutoRepeat: true
                    onClicked: rewindForward()
                    //onPlatformReleased: rewindForwardStop()
                }
                Button {
                    id: plrNext
                    iconSource: "image://theme/icon-m-toolbar-mediacontrol-next-white"
                    width: height
                    platformStyle: ButtonStyle { inverted: true }
                    enabled: vkSubpageAudioPlayer.isControlsEnabled
                    onClicked: next()
                }
            }
        }
    }

    Audio {
        id: audio

        onStatusChanged: {
            if (status == Audio.EndOfMedia) {
                next()
            }
        }
    }
}
