// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import VkPages 1.0

Item {
    property color loadingBkgColor: "darkgrey"
    property string loadingText: "Загрузка"
    property variant basePageService
    property int loadingState: basePageService.status

    Rectangle {
        id: busyScreen

        anchors.fill: parent
        color: loadingBkgColor
        visible: false

        BusyIndicator {
            id: loadingIndicator
            anchors.centerIn: parent
            running: true
        }
        Label {
            id: loadingTextLabel
            text: loadingText
            anchors {
                top: loadingIndicator.bottom
                topMargin: 10
                horizontalCenter: loadingIndicator.horizontalCenter
            }
        }
        Item {
            id: retryBlock
            anchors {
                top: loadingTextLabel.bottom
                topMargin: 10
                horizontalCenter: loadingIndicator.horizontalCenter
            }

            Label {
                id: retryLabel
                text: "Ошибка"
                color: "red"
                anchors {
                    top: parent.top
                    horizontalCenter: parent.horizontalCenter
                }
            }
            Button {
                anchors {
                    top: retryLabel.bottom
                    topMargin: 10
                    horizontalCenter: parent.horizontalCenter
                }
                text: "Повторить"
                onClicked: basePageService.updateData()
            }
        }
    }

    onLoadingStateChanged: {
        if (loadingState === VkPageService.Ready || loadingState === VkPageService.Null) {
            showPageContent()
        } else if (loadingState === VkPageService.Error) {
            showFailScreen()
        } else {
            showBusyScreen()
        }
    }

    // loading
    function showBusyScreen() {
        // process loading
        loadingIndicator.running = true
        loadingIndicator.visible = true
        retryBlock.visible       = false
        for (var i = 0; i < children.length; ++i) {
            if (children[i] === busyScreen) {
                children[i].visible = true
            } else {
                children[i].visible = false
            }
        }
    }

    // notice loaded
    function showPageContent() {
        for (var i = 0; i < children.length; ++i) {
            if (children[i] === busyScreen) {
                children[i].visible = false
            } else {
                children[i].visible = true
            }
        }
        loadingIndicator.running = false
    }

    // notice failed
    function showFailScreen() {
        // process loading
        loadingIndicator.running = false
        loadingIndicator.visible = false
        retryBlock.visible       = true
        for (var i = 0; i < children.length; ++i) {
            if (children[i] === busyScreen) {
                children[i].visible = true
            } else {
                children[i].visible = false
            }
        }
    }
}
