// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import VkPages 1.0
import "../elements"

Item {
    id: vkSubpageFeed

    property variant feedService

    property alias feedListModel: feedMessages.model
    property bool isFeedListLoading: feedService.feedLoading
    property int feedServerCount: feedService.feedServerCount
    property int feedServerOffset: feedService.feedServerOffset
    property string senderName: ""
    property string senderAvatar: ""

    // functions and signals
    function moreFeedClicked()
    {
        feedService.getMoreFeed(40)
    }
    function reloadFeedClicked()
    {
        feedService.refreshFeed()
    }
    function setIndex(idx) {
        feedMessages.positionViewAtIndex(idx, ListView.Beginning);
//        feedMessages.currentIndex = idx;
//        feedMessages.highlightFollowsCurrentItem = true;
//        feedMessages.highlightMoveDuration = 150;
//        feedMessages.highlightRangeMode = ListView.StrictlyEnforceRange;
    }
    signal showAccountOwnerPage()
    signal viewFeedItem(int idx)

    // internal
    property int  feedListModelCount: feedListModel.count
    property bool needInitialFeedLoading: feedListModelCount === 0


    // empty list label
    VkCoreText {
        id: emptyListLabel
        anchors {
            fill: parent
            leftMargin: 20
            rightMargin: 20
        }

        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        text: "Нет новостей"
        font.bold: true
        font.pixelSize: 60
        color: "darkgrey"
        visible: (feedServerCount === 0) && !isFeedListLoading
    }
    ListView {
        id: feedMessages
        anchors.fill: parent
        pressDelay: 100
        cacheBuffer: 400
        delegate: VkFeedListItem {
            onViewFeedItem: vkSubpageFeed.viewFeedItem(idx)
        }
        header: Column {
            anchors {
                left: parent ? parent.left : undefined
                right: parent ? parent.right : undefined
            }
            spacing: 10
            VkCorePageHeader {
                id: feedPageHeader
                headerLabelText: "Новости"

                Button {
                    anchors {
                        left: parent.left
                        verticalCenter: parent.verticalCenter
                        leftMargin: 10
                    }

                    iconSource: "image://theme/icon-m-toolbar-home"
                    width: height
                    onClicked: showAccountOwnerPage()
                }
            }
            Item {
                anchors {
                    left: parent.left
                    right: parent.right
                }
                height: btnReload.height
                VkCoreLabeledNumber {
                    anchors {
                        left: parent.left
                        right: btnReload.left
                        verticalCenter: parent.verticalCenter
                        leftMargin: 20
                        rightMargin: 20
                    }

                    property bool usePrefix: feedServerOffset < feedServerCount

                    number: feedServerCount >= 0 ? feedServerCount : 0
                    prefix: usePrefix ? (feedListModelCount + " из ") : ""
                    label: "новостей"
                    label1: usePrefix ? "новости" : "новость"
                    label234: usePrefix ? "новостей" : "новости"
                    hideZero: true
                }
                Button {
                    id: btnReload
                    anchors {
                        right: parent.right
                        top: parent.top
                        rightMargin: 20
                    }
                    iconSource: "image://theme/icon-m-toolbar-refresh"
                    width: height
                    onClicked: reloadFeedClicked()
                }
            }
            VkCoreListElementDivider {
                anchors {
                    leftMargin: 0
                    rightMargin: 0
                }
            }
            Item {
                id: dummy
                anchors {
                    left: parent.left
                    right: parent.right
                }
                height: 10
            }
        }
        footer: VkCoreListFooter {
            anchors {
                leftMargin: 20
                rightMargin: 20
            }

            needInitialLoad: (feedService.status === VkPageService.Ready && vkSubpageFeed.visible) ? needInitialFeedLoading : false
            isLoading: isFeedListLoading
            showDivider: false
            onMoreClicked: moreFeedClicked()

            visible: /*feedServerCount < 0 || */feedServerOffset == 0 || feedServerOffset < feedServerCount
        }
    }
    ScrollDecorator {
        flickableItem: feedMessages
    }
}
