// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import VkPages 1.0
import "../elements"

VkSubpageBase {

    property variant friendsService

    loadingText: "Загрузка списка друзей"
    basePageService: friendsService

    // internal
    property int intervalOnlineUpdate: 5 * 60 * 1000

    // filtering
    property int filterFriendListId: -1
    property bool filterFriendListOnline: false

    onFilterFriendListIdChanged: doFilterContacts()
    onFilterFriendListOnlineChanged: doFilterContacts()

    function doFilterContacts()
    {
        friendsService.filterFriendList(filterFriendListId, filterFriendListOnline)
    }

    // update online status
    Timer {
        id: timerUpdateOnline
        interval: intervalOnlineUpdate
        running: false
        repeat: true

        onTriggered: {
            friendsService.updateOnlineStatus()
        }
    }
    onLoadingStateChanged: {
        if (loadingState === VkPageService.Ready) {
            timerUpdateOnline.running = true
        }
    }

    // friend list dialog
    ListModel {
        id: friendListDialogModel
        ListElement { name: "Все друзья"; listId: -1 }
    }
    SelectionDialog {
        id: friendListDialog
        titleText: "Выберите список друзей"
        selectedIndex: 0

        model: friendListDialogModel

        onSelectedIndexChanged: {
            var friendListId = -1
            if (friendListDialog.selectedIndex >= 0) {
                friendListId = model.get(friendListDialog.selectedIndex).listId
            }
            filterFriendListId = friendListId
        }
    }

    Connections {
        target: friendsService
        onFriendListsModelChanged: {
            friendListDialogModel.clear()
            friendListDialogModel.append({"name":"Все друзья", "listId":-1})
//            friendListDialogModel.append({"name":"Лучшие друзья", "listId":28})
//            friendListDialogModel.append({"name":"Родственники", "listId":29})
//            friendListDialogModel.append({"name":"Коллеги", "listId":27})
//            friendListDialogModel.append({"name":"Друзья по вузу", "listId":25})
//            friendListDialogModel.append({"name":"Друзья по школе", "listId":26})
            for (var i = 0, imax = friendsService.friendListsModel.length; i < imax; ++i) {
                friendListDialogModel.append({"name":friendsService.friendListsModel[i].name, "listId":friendsService.friendListsModel[i].listId})
            }
        }
    }


    Item {
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            bottom: parent.bottom
            leftMargin: 20
            rightMargin: 20
        }
        VkCoreText {
            id: emptyListLabel
            anchors.fill: parent

            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text: (filterFriendListId < 0 ? "Нет друзей" : "В этом списке нет друзей") + (filterFriendListOnline ? " в сети" : "")
            font.bold: true
            font.pixelSize: 60
            color: "darkgrey"
            visible: accOwnerContactCardModel.count === 0
        }
    }
    ListView {
        id: listFriends
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            bottom: parent.bottom
        }
        model: accOwnerContactCardModel
        delegate: VkFriendsContactCard {
            anchors {
                leftMargin: 20
                rightMargin: 20
            }
        }
        header: Column {
            anchors {
                left: parent ? parent.left : undefined
                right: parent ? parent.right : undefined
            }
            spacing: 10
            VkCorePageHeader {
                id: friendsPageHeader
                headerLabelText: "Мои друзья"

                BusyIndicator {
                    anchors {
                        verticalCenter: parent.verticalCenter
                        left: parent.left
                        leftMargin: 20
                    }
                    running: friendsService.friendInfoUpdating
                    visible: friendsService.friendInfoUpdating
                }
            }
            Button {
                iconSource: "image://theme/icon-m-common-combobox-arrow"
                //style: ListButtonStyle {}
                text: friendListDialog.selectedIndex < 0 ? "Выберите список" : friendListDialog.model.get(friendListDialog.selectedIndex).name
                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: 20
                    rightMargin: 20
                }
                onClicked: friendListDialog.open()
            }
            Item {
                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: 20
                    rightMargin: 20
                }
                height: onlineFilter.height + 10
                Label {
                    anchors {
                        left: parent.left
                        right: onlineFilter.left
                        leftMargin: -10
                        rightMargin: 10
                        verticalCenter: onlineFilter.verticalCenter
                    }

                    text: "Друзья в сети"
                    horizontalAlignment: Text.AlignRight
                }
                Switch {
                    id: onlineFilter
                    anchors {
                        right: parent.right
                        top: parent.top
                    }
                    checked: filterFriendListOnline

                    onCheckedChanged: {
                        filterFriendListOnline = checked
                    }
                }
            }
            VkCoreLabeledNumber {
                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: 20
                    rightMargin: 20
                }

                number: accOwnerContactCardModel.count
                label: "друзей"
                label1: "друг"
                label234: "друга"

                hideZero: true
            }
            VkCoreListElementDivider {
                anchors {
                    leftMargin: 0
                    rightMargin: 0
                }
            }
            Item {
                id: dummy
                anchors {
                    left: parent.left
                    right: parent.right
                }
                height: 10
            }
        }
    }
    ScrollDecorator {
        flickableItem: listFriends
    }

    Component.onCompleted: {
//        friendsService.addCustomFriendList(28)
//        friendsService.addCustomFriendList(29)
//        friendsService.addCustomFriendList(27)
//        friendsService.addCustomFriendList(25)
//        friendsService.addCustomFriendList(26)
    }
}
