// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import VkPages 1.0
import "../elements"

VkSubpageBase {

    property variant messagesService

    loadingText: messageListMode ? "Загрузка сообщений" : "Загрузка диалога"
    basePageService: messagesService

    property bool messageListMode: true

    function showOwnerMessages()
    {
        messageListMode = true
    }
    function showDialogWith(uid)
    {
        messageList.msgItemClickedFromDlg(uid, 0)
    }

    Item {
        id: msgListBlock
        anchors.fill: parent

        Component {
            id: msgListDelegateDlg
            VkMsgListDlgItem {
                id: msgListDelegateDlgItem
                anchors {
                    leftMargin: 20
                    rightMargin: 20
                }
                Component.onCompleted: msgListDelegateDlgItem.msgItemClicked.connect(messageList.msgItemClickedFromDlg)
            }
        }
        Component {
            id: msgListDelegateMsg
            VkMsgListItem {
                id: msgListDelegateMsgItem
                anchors {
                    leftMargin: 20
                    rightMargin: 20
                }
                Component.onCompleted: msgListDelegateMsgItem.msgItemClicked.connect(messageList.msgItemClickedFromList)
            }
        }
        Component {
            id: dialogListDelegate
            VkDlgListItem {
                anchors {
                    leftMargin: 20
                    rightMargin: 20
                }
            }
        }

        VkSubpageMessagesList {
            id: messageList
            anchors.fill: parent

            // message signals handlers
            signal msgItemClickedFromList(int uid, int mid)
            signal msgItemClickedFromDlg (int uid, int mid)
            onMsgItemClickedFromList: {
                messagesService.initNewDialogWithMsg(uid, mid)
                messageListMode = false
            }
            onMsgItemClickedFromDlg: {
                messagesService.initNewDialog(uid)
                messageListMode = false
            }

            msgListTypeIn:      true
            msgListTypeDialogs: true
            msgListModel:       msgListTypeDialogs ?
                                    msgModelDialogList :
                                    (msgListTypeIn ? msgModelIn : msgModelOut)
            msgListDelegate:    msgListTypeDialogs ? msgListDelegateDlg : msgListDelegateMsg

            isMsgListLoading:   msgListTypeDialogs ?
                                    messagesService.msgDialogListLoading :
                                    (msgListTypeIn ?
                                         messagesService.msgInLoading :
                                         messagesService.msgOutLoading)
            msgServerCount:     msgListTypeDialogs ?
                                    messagesService.msgDialogListServerCount :
                                    (msgListTypeIn ?
                                         messagesService.msgInServerCount :
                                         messagesService.msgOutServerCount)
            msgServerOffset:    msgListTypeDialogs ?
                                    messagesService.msgDialogListServerOffset :
                                    (msgListTypeIn ?
                                         messagesService.msgInServerOffset :
                                         messagesService.msgOutServerOffset)

            onMoreMesagesClicked: {
                var msgMoreCount = 20
                var msgMorePreviewLen = 65
                var msgMorePreviewLenDlg = 55
                if (msgListTypeDialogs) {
                    messagesService.getMoreDialogList(msgMoreCount, msgMorePreviewLenDlg)
                } else if (msgListTypeIn) {
                    messagesService.getMoreIn(msgMoreCount, msgMorePreviewLen)
                } else {
                    messagesService.getMoreOut(msgMoreCount, msgMorePreviewLen)
                }
            }

            onReloadMesagesClicked: {
                if (msgListTypeDialogs) {
                    messagesService.refreshDialogList()
                } else if (msgListTypeIn) {
                    messagesService.refreshIn()
                } else {
                    messagesService.refreshOut()
                }
            }

            visible: messageListMode
        }

        VkSubpageMessagesDialog {
            id: dialogWithOpponent
            anchors.fill: parent

            msgListModel:       msgModelDialog
            msgListDelegate:    dialogListDelegate

            isMsgListLoading:   messagesService.msgDialogLoading
            msgServerCount:     messagesService.msgDialogServerCount
            msgServerOffset:    messagesService.msgDialogServerOffset

            onMoreMesagesClicked: {
                var msgMoreCount = 20
                messagesService.getMoreDialog(msgMoreCount)
            }
            onReloadMesagesClicked: {
                messagesService.refreshDialog()
            }
            onSwitchToMessagesClicked: messageListMode = true

            visible: !messageListMode
        }
    }
}
