// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1
import VkPages 1.0
import "../elements"

Item {

    property alias msgListModel: listMessages.model
    property alias msgListDelegate: listMessages.delegate
    property bool isMsgListLoading: false
    property int msgServerCount: 0
    property int msgServerOffset: 0

    signal moreMesagesClicked()
    signal reloadMesagesClicked()
    signal switchToMessagesClicked()

    // internal
    property int  msgListModelCount: msgListModel.count
    property bool needInitialMsgLoading: msgListModelCount === 0
    property string headerTitleWith: (vkAppService.isSomeCharInString(messagesService.dialogOpponentNameIns, 0, "Сс") &&
                                      vkAppService.isSomeCharInString(messagesService.dialogOpponentNameIns, 1, "БВГДЖЗКЛМНПРСТФХЦЧШЩЪЬбвгджзклмнпрстфхцчшщъь")) ? " со " : " с "


    // empty list label
    VkCoreText {
        id: emptyListLabel
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            bottom: parent.bottom
            leftMargin: 20
            rightMargin: 20
        }

        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        text: "Нет сообщений"
        font.bold: true
        font.pixelSize: 60
        color: "darkgrey"
        visible: (msgServerCount === 0) && !isMsgListLoading
    }
    ListView {
        id: listMessages
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            bottom: sendMsgRect.top
        }
        pressDelay: 100
        header: Column {
            anchors {
                left: parent ? parent.left : undefined
                right: parent ? parent.right : undefined
            }
            spacing: 10
            VkCorePageHeader {
                id: messagesPageHeader

                ListButton {
                    id: btnBackToMessages
                    anchors {
                        left: parent.left
                        verticalCenter: parent.verticalCenter
                        leftMargin: 10
                    }
                    text: "Сообщения"
                    onClicked: switchToMessagesClicked()
                }
                VkCoreAvatar {
                    id: val_avatar
                    anchors {
                        right: parent.right
                        verticalCenter: parent.verticalCenter
                        rightMargin: 10
                    }

                    imgSrc: messagesService.dialogOpponentPhoto
                    online: messagesService.dialogOpponentOnline

                    VkCoreSelectionArea {
                        anchors.fill: parent
                        onClicked: mainPage.showUserPage(messagesService.dialogOpponentUserId)
                    }
                }
            }
            VkCoreText {
                id: dlgHeaderText
                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: 20
                    rightMargin: 20
                }
                text: "Диалог" + headerTitleWith + messagesService.dialogOpponentNameIns
            }
            VkCoreText {
                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: 20
                    rightMargin: 20
                }
                color: "#777777"
                font.pixelSize: 16
                visible: !messagesService.dialogOpponentOnline && messagesService.dialogOpponentOnline_time_valid
                text: messagesService.dialogOpponentName +
                      (messagesService.dialogOpponentSex > 0 ? messagesService.dialogOpponentSex === 1 ? " была" : " был" : "") + " в сети " +
                      vkAppService.dateTimePassedToString(messagesService.dialogOpponentOnline_time, vkAppService.curDateTimeUpdated, " в ", false, 0)
            }
            Item {
                anchors {
                    left: parent.left
                    right: parent.right
                }
                height: btnReload.height
                VkCoreLabeledNumber {
                    anchors {
                        left: parent.left
                        right: btnReload.left
                        verticalCenter: btnReload.verticalCenter
                        leftMargin: 20
                        rightMargin: 20
                    }

                    property bool usePrefix: msgServerOffset < msgServerCount

                    number: msgServerCount >= 0 ? msgServerCount : 0
                    prefix: usePrefix ? (msgListModelCount + " из ") : ""
                    label: "сообщений"
                    label1: usePrefix ? "сообщения" : "сообщение"
                    label234: usePrefix ? "сообщений" : "сообщения"
                    hideZero: true
                }
                Button {
                    id: btnReload
                    anchors {
                        right: parent.right
                        top: parent.top
                        rightMargin: 20
                    }
                    iconSource: "image://theme/icon-m-toolbar-refresh"
                    width: height
                    onClicked: reloadMesagesClicked()
                }
            }
            VkCoreListElementDivider {
                anchors {
                    leftMargin: 0
                    rightMargin: 0
                }
            }
            Item {
                id: dummy
                anchors {
                    left: parent.left
                    right: parent.right
                }
                height: 10
            }
        }
        footer: VkCoreListFooter {
            anchors {
                leftMargin: 20
                rightMargin: 20
            }

            needInitialLoad: loadingState === VkPageService.Ready ? needInitialMsgLoading : false
            isLoading: isMsgListLoading
            showDivider: false
            onMoreClicked: moreMesagesClicked()

            visible: msgServerCount < 0 || msgServerOffset < msgServerCount
        }
    }
    ScrollDecorator {
        flickableItem: listMessages
    }

    // send message
    Rectangle {
        id: sendMsgRect
        anchors {
            left: parent.left
            right: parent.right
            bottom: parent.bottom
        }
        height: sendMsgInput.implicitHeight

        color: "lightgray"

        states: [
            State {
                name: "maximized"
                when: sendMsgInput.activeFocus
                PropertyChanges { target: sendMsgRect; height: sendMsgInput.height + sendMsgColumn.spacing + sendMsgButton.height }
            },
            State {
                name: "minimized"
                when: !sendMsgInput.activeFocus
                PropertyChanges { target: sendMsgRect; height: sendMsgInput.implicitHeight }
            }
        ]

        state: "minimized"

        transitions: [
            Transition {
                to: "maximized"
                NumberAnimation { properties: "height"; easing.type: Easing.OutCubic; duration: 500 }
            },
            Transition {
                to: "minimized"
                NumberAnimation { properties: "height"; easing.type: Easing.InCubic; duration: 500 }
            }
        ]

        Column {
            id: sendMsgColumn
            spacing: 2
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }

            TextArea {
                id: sendMsgInput
                anchors {left: parent.left; right: parent.right}
                placeholderText: "Напишите сообщение"
                textFormat: TextEdit.PlainText
                wrapMode: TextEdit.Wrap
            }
            Button {
                id: sendMsgButton
                anchors {right: parent.right}
                text: "Отправить"
                onClicked: {
                    messagesService.dlgSendMessage(sendMsgInput.text)
                    sendMsgInput.text = ""
                }
                enabled: sendMsgInput.text.length > 0
            }
        }
    }
}
