// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import VkPages 1.0
import "../elements"

Item {

    property bool msgListTypeIn: true
    property bool msgListTypeDialogs: false
    property alias msgListModel: listMessages.model
    property alias msgListDelegate: listMessages.delegate
    property bool isMsgListLoading: false
    property int msgServerCount: 0
    property int msgServerOffset: 0

    signal moreMesagesClicked()
    signal reloadMesagesClicked()

    // internal
    property int  msgListModelCount: msgListModel.count - 1
    property bool needInitialMsgLoading: msgServerCount < 0


    // empty list label
    VkCoreText {
        id: emptyListLabel
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            bottom: parent.bottom
            leftMargin: 20
            rightMargin: 20
        }

        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        text: msgListTypeDialogs ? "Нет диалогов" : "Нет сообщений"
        font.bold: true
        font.pixelSize: 60
        color: "darkgrey"
        visible: (msgServerCount === 0) && !isMsgListLoading
    }
    ListView {
        id: listMessages
        anchors.fill: parent
        header: Column {
            anchors {
                left: parent ? parent.left : undefined
                right: parent ? parent.right : undefined
            }
            spacing: 10
            VkCorePageHeader {
                id: messagesPageHeader
                headerLabelText: "Мои " + (msgListTypeDialogs ? "диалоги" : "сообщения")
            }
            Item {
                anchors {
                    left: parent.left
                    right: parent.right
                }
                height: btnReload.height

                VkCoreImageSwitch {
                    id: swMsgListTypeDialogs
                    anchors {
                        left: parent.left
                        verticalCenter: parent.verticalCenter
                        leftMargin: 15
                    }

                    switchImage: msgListTypeDialogs ? "../../icons/vk-icon-msg-dialogs.png" : "../../icons/vk-icon-msg-lists.png"

                    checked: !msgListTypeDialogs
                    onCheckedChanged: msgListTypeDialogs = !checked
                }
                Button {
                    id: btnReload
                    anchors {
                        right: parent.right
                        top: parent.top
                        rightMargin: 20
                    }
                    iconSource: "image://theme/icon-m-toolbar-refresh"
                    width: height
                    onClicked: reloadMesagesClicked()
                }
                ButtonRow {
                    id: msgListTypeInOutSwitch
                    checkedButton: msgListTypeIn ? msgListTypeInOutSwitchIn : msgListTypeInOutSwitchOut
                    visible: !msgListTypeDialogs
                    anchors {
                        left: swMsgListTypeDialogs.right
                        right: btnReload.left
                        top: parent.top
                        leftMargin: 10
                        rightMargin: 10
                    }

                    Button {
                        id: msgListTypeInOutSwitchIn
                        text: "Входящие"
                        onClicked: msgListTypeIn = true
                    }
                    Button {
                        id: msgListTypeInOutSwitchOut
                        text: "Исходящие"
                        onClicked: msgListTypeIn = false
                    }
                }
            }
            VkCoreLabeledNumber {
                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: 20
                    rightMargin: 20
                }

                property bool usePrefix: msgServerOffset < msgServerCount

                number: msgServerCount >= 0 ? msgServerCount : 0
                prefix: usePrefix ? (msgListModelCount + " из ") : ""
                label: msgListTypeDialogs ? "диалогов" : "сообщений"
                label1: msgListTypeDialogs ?
                            (usePrefix ? "диалога" : "диалог") :
                            (usePrefix ? "сообщения" : "сообщение")
                label234: msgListTypeDialogs ?
                              (usePrefix ? "диалогов" : "диалога") :
                              (usePrefix ? "сообщений" : "сообщения")
                hideZero: true
            }
            VkCoreListElementDivider {
                anchors {
                    leftMargin: 0
                    rightMargin: 0
                }
            }
            Item {
                id: dummy
                anchors {
                    left: parent.left
                    right: parent.right
                }
                height: 10
            }
        }
        footer: VkCoreListFooter {
            anchors {
                leftMargin: 20
                rightMargin: 20
            }

            needInitialLoad: loadingState === VkPageService.Ready ? needInitialMsgLoading : false
            isLoading: isMsgListLoading
            onMoreClicked: moreMesagesClicked()

            visible: msgServerCount < 0 || msgServerOffset < msgServerCount
        }
    }
    ScrollDecorator {
        flickableItem: listMessages
    }
}
