// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import VkPages 1.0
import "../elements"

VkSubpageBase {
    id: vkSubpagePhotoView

    property variant photosService
    basePageService: photosService

    property alias photoListModel: listPhotoView.model

    // item properties
    property string photoDesc: ""
    property int    photoId: 0
    property string photoOwner_id: "0"      // fix negative int id
    property int    photo_likes_count: 0
    property bool   photo_likes_user_likes: false
    property bool   photo_likes_can_like: false
    property bool   photo_likes_busy: false

    // signals
    signal backToAlbumClicked()

    // functions
    function setIndex(idx) {
        listPhotoView.positionViewAtIndex(idx, ListView.Center);
        listPhotoView.currentIndex = -1;    // forget prev cur item
        listPhotoView.currentIndex = idx;
        listPhotoView.highlightFollowsCurrentItem = true;
        listPhotoView.highlightMoveDuration = 150;
        listPhotoView.highlightRangeMode = ListView.StrictlyEnforceRange;
    }

    // internal
    property string internalAlbumTitle: isPhotoViewerExternal ? "" : " - " + photosService.albumTitle

    // ui settings
    property int    maxCoverWidth:      130
    property int    maxCoverHeight:     130

    Item {
        anchors {
            fill: parent
            leftMargin: 20
            rightMargin: 20
        }
        VkCoreText {
            id: emptyListLabel
            anchors.fill: parent

            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text: "Нет фотографий"
            font.bold: true
            font.pixelSize: 60
            color: "darkgrey"
            visible: photoListModel.count === 0
        }
    }

    // photo view component
    Component {
        id: photoViewComponent

        Item {
            id: wrapper
            width: listPhotoView.width
            height: listPhotoView.height

            VkCoreScaledImage {
                id: photoViewImg
                anchors.centerIn: parent

                busyIndicatorStyle: BusyIndicatorStyle { inverted: true; size: "" }

                imgWidth:  parent.width
                imgHeight: parent.height
                imgScaledWidth: parent.width
                imgScaledHeight: parent.height
                imgSrc:    src_xbig_safe
                imgLoader: "photo"
            }

            // photo properties to global
            property int curIdx: ListView.view.currentIndex
            Component.onCompleted: setAllLocal()
            onCurIdxChanged: setAllLocal()
            function setAllLocal()
            {
                if (curIdx === index) {
                    photoDesc              = text
                    photoId                = pid
                    photoOwner_id          = owner_id
                    photo_likes_count      = likes_count
                    photo_likes_user_likes = likes_user_likes
                    photo_likes_can_like   = likes_can_like
                    photo_likes_busy       = likes_busy
                }
            }
            property int    local_likes_count:      likes_count
            property bool   local_likes_user_likes: likes_user_likes
            property bool   local_likes_can_like:   likes_can_like
            property bool   local_likes_busy:       likes_busy
            onLocal_likes_countChanged:      if (curIdx === index) { photo_likes_count      = likes_count }
            onLocal_likes_user_likesChanged: if (curIdx === index) { photo_likes_user_likes = likes_user_likes }
            onLocal_likes_can_likeChanged:   if (curIdx === index) { photo_likes_can_like   = likes_can_like }
            onLocal_likes_busyChanged:       if (curIdx === index) { photo_likes_busy       = likes_busy }
        }
    }

    // photo list
    Rectangle {
        id: listPhotoViewBackground
        anchors.fill: parent

        color: "black"

        ListView {
            id: listPhotoView
            anchors.fill: parent

            delegate: photoViewComponent

            orientation: ListView.Horizontal
            snapMode: ListView.SnapOneItem

            // ensure current item change when flick list
            highlightFollowsCurrentItem: true
            highlightMoveDuration: 150
            highlightRangeMode: ListView.StrictlyEnforceRange

            MouseArea {
                id: infoBarShowControl
                anchors.fill: parent

                state: "infoBarVisible"

                states: [
                    State {
                        name: "infoBarVisible"
                        PropertyChanges {target: photoViewTopPanel; anchors.topMargin: 0}
                        PropertyChanges {target: photoViewBottomPanel; anchors.bottomMargin: 0}
                    },
                    State {
                        name: "infoBarHidden"
                        PropertyChanges {target: photoViewTopPanel; anchors.topMargin: -height}
                        PropertyChanges {target: photoViewBottomPanel; anchors.bottomMargin: -height}
                    }
                ]
                transitions: [
                    Transition {
                        to: "*"
                        PropertyAnimation {target: photoViewTopPanel; properties: "anchors.topMargin"; duration: 400; easing.type: Easing.OutQuad}
                        PropertyAnimation {target: photoViewBottomPanel; properties: "anchors.bottomMargin"; duration: 400; easing.type: Easing.OutQuad}
                    }
                ]
                onClicked: if (state === "infoBarVisible") {
                               state = "infoBarHidden"
                           } else {
                               state = "infoBarVisible"
                           }
            }
        }

        // control and info panels
        Rectangle {
            id: photoViewTopPanel
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }

            color: "#50000000"
            height: photoViewTopPanelText.height
            VkCoreText {
                id: photoViewTopPanelText

                anchors {
                    left: parent.left
                    verticalCenter: parent.verticalCenter
                    leftMargin: 20
                }

                text: (listPhotoView.currentIndex + 1) + " из " + photoListModel.count + internalAlbumTitle
                color: "white"
                wrapMode: Text.NoWrap
            }
        }

        Item {
            id: photoViewBottomPanel
            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
            }

            height: photoViewBottomPanelControl.height + photoViewBottomPanelInfo.height

            Rectangle {
                id: photoViewBottomPanelControl
                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                }

                color: "#50000000"
                height: photoViewBottomPanelTool.height

                ToolBar {
                    id: photoViewBottomPanelTool
                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    opacity: 0.6
                    platformStyle: ToolBarStyle { inverted: true }
                    tools: ToolBarLayout {
                        ToolIcon {
                            platformIconId: "toolbar-back-white"
                            onClicked: backToAlbumClicked()
                        }
                        VkCoreLikeControlShort {
                            property int likes_count: photo_likes_count
                            property bool likes_user_likes: photo_likes_user_likes
                            property bool likes_can_like: photo_likes_can_like
                            property bool likes_busy: photo_likes_busy

                            busyIndicatorStyle: BusyIndicatorStyle { inverted: true }

                            onLikeClicked: photosService.photoAddLike(listPhotoView.currentIndex, photoOwner_id, photoId, isPhotoViewerExternal)
                            onDislikeClicked: photosService.photoDeleteLike(listPhotoView.currentIndex, photoOwner_id, photoId, isPhotoViewerExternal)
                        }
                    }
                }
            }

            Rectangle {
                id: photoViewBottomPanelInfo
                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: photoViewBottomPanelControl.top
                }

                color: "#50000000"
                height: photoViewBottomPanelText.visible ? Math.min(photoViewBottomPanelText.height, 300) : 0
                clip: true

                VkCoreText {
                    id: photoViewBottomPanelText;
                    anchors {
                        top: parent.top
                        left: parent.left
                        right: parent.right
                    }

                    text: photoDesc
                    color: "white"
                    visible: text.length > 0
                }
            }
        }
    }
}
