// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1
import VkPages 1.0
import "../elements"

VkSubpageBase {
    id: vkSubpagePhotos

    property variant photosService
    loadingText: isPhotoListMode ? "Загрузка фотографий" : "Загрузка фотоальбомов"
    basePageService: photosService

    // signas
    signal showAccountOwnerPhotos()
    signal activatePhotoViewer(int photoIdx)

    property alias albumListModel: gridPhotoAlbums.model
    property alias photoListModel: gridPhotoList.model

    property bool isPhotoListMode: false

    // ui settings
    property int    maxCoverWidth:      130
    property int    maxCoverHeight:     100//130 - fix bug GridView crash

    function showAlbumList()
    {
        isPhotoListMode = false;
        gridPhotoAlbums.positionViewAtBeginning()
    }

    Item {
        anchors {
            fill: parent
            leftMargin: 20
            rightMargin: 20
        }
        VkCoreText {
            id: emptyListLabel
            anchors.fill: parent

            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text: isPhotoListMode ? "Нет фотографий" : "Нет фотоальбомов"
            font.bold: true
            font.pixelSize: 60
            color: "darkgrey"
            visible: isPhotoListMode ? (photoListModel.count === 0) : (albumListModel.count === 0)
        }
    }

    // album list
    Item {
        anchors.fill: parent
        GridView {
            id: gridPhotoAlbums
            anchors.fill: parent
            delegate: VkPhotosAlbumCover {
                width: GridView.view.cellWidth
                height: GridView.view.cellHeight
                coverWidth: GridView.view.coverWidth
                coverHeight: GridView.view.coverHeight

                onAlbumItemClicked: {
                    photosService.loadAlbum(aid)
                    isPhotoListMode = true
                }
            }

            property int    coverWidth:     vkSubpagePhotos.maxCoverWidth
            property int    coverHeight:    vkSubpagePhotos.maxCoverHeight
            property int albumMinCellWidth: coverWidth + 30
            property int albumCellLineCount: width > albumMinCellWidth ? width / albumMinCellWidth : 1
            cellWidth: width > albumCellLineCount ? width / albumCellLineCount : albumMinCellWidth
            cellHeight: Math.min(cellWidth, coverHeight + 40)    // fix bug GridView crash: height must be <= width

            Connections {
                target: photosService
                onAlbumListLoaded: gridPhotoAlbums.positionViewAtBeginning()
            }

            header: Column {
                anchors {
                    left: parent ? parent.left : undefined
                    right: parent ? parent.right : undefined
                }
                spacing: 10
                VkCorePageHeader {
                    headerLabelText: photosService.isAccountOwner ? "Мои фотоальбомы" : "Фотоальбомы " + photosService.photoOwnerFName

                    VkCoreAvatar {
                        anchors {
                            right: parent.right
                            verticalCenter: parent.verticalCenter
                            rightMargin: 10
                        }

                        imgSrc: photosService.photoOwnerAvatar
                        online: photosService.photoOwnerOnline

                        VkCoreSelectionArea {
                            anchors.fill: parent
                            onClicked: mainPage.showUserPage(photosService.photoOwnerUid)
                        }

                        visible: !photosService.isAccountOwner
                    }
                }
                Item {
                    id: buttonPlaceholder
                    // fix header height change artefacts

                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    height: !photosService.isAccountOwner ? btnToOwherPhotos.height : 0

                    Button {
                        id: btnToOwherPhotos
                        anchors {
                            left: parent.left
                            right: parent.right
                            leftMargin: 20
                            rightMargin: 20
                        }

                        text: "К моим фотографиям"
                        visible: !photosService.isAccountOwner
                        onClicked: showAccountOwnerPhotos()
                    }
                }
                VkCoreLabeledNumber {
                    anchors {
                        left: parent.left
                        right: parent.right
                        leftMargin: 20
                        rightMargin: 20
                    }

                    number: albumListModel.count
                    label: "альбомов"
                    label1: "альбом"
                    label234: "альбома"

                    hideZero: true
                }
                VkCoreListElementDivider {
                    anchors {
                        leftMargin: 0
                        rightMargin: 0
                    }
                }
                Item {
                    id: albumHeaderDummy
                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    height: 10
                }
            }
            visible: !isPhotoListMode
        }
        ScrollDecorator {
            flickableItem: gridPhotoAlbums
            visible: !isPhotoListMode
        }
        visible: !isPhotoListMode
    }

    // photo list
    Item {
        anchors.fill: parent
        GridView {
            id: gridPhotoList
            anchors.fill: parent
            delegate: VkPhotosItemPreview {
                width: GridView.view.cellWidth
                height: GridView.view.cellHeight
                previewWidth: GridView.view.coverWidth
                previewHeight: GridView.view.coverHeight

                onPhotoItemClicked: activatePhotoViewer(idx)
            }
            property int    coverWidth:     vkSubpagePhotos.maxCoverWidth
            property int    coverHeight:    vkSubpagePhotos.maxCoverHeight
            property int albumMinCellWidth: coverWidth + 10
            property int albumCellLineCount: width > albumMinCellWidth ? width / albumMinCellWidth : 1
            cellWidth: width > albumCellLineCount ? width / albumCellLineCount : albumMinCellWidth
            cellHeight: Math.min(cellWidth, coverHeight + 10)    // fix bug GridView crash: height must be <= width

            Connections {
                target: photosService
                onAlbumLoaded: gridPhotoList.positionViewAtBeginning()
            }

            header: Column {
                anchors {
                    left: parent ? parent.left : undefined
                    right: parent ? parent.right : undefined
                }
                spacing: 10
                VkCorePageHeader {
                    //headerLabelText: photosService.isAccountOwner ? "Мои фотографии" : "Фотографии " + photosService.photoOwnerFName

                    ListButton {
                        id: btnBackToPhotoAlbums
                        anchors {
                            left: parent.left
                            verticalCenter: parent.verticalCenter
                            leftMargin: 20
                        }
                        text: "Все альбомы"
                        onClicked: isPhotoListMode = false
                    }
                    VkCoreAvatar {
                        anchors {
                            right: parent.right
                            verticalCenter: parent.verticalCenter
                            rightMargin: 10
                        }

                        imgSrc: photosService.photoOwnerAvatar
                        online: photosService.photoOwnerOnline

                        VkCoreSelectionArea {
                            anchors.fill: parent
                            onClicked: mainPage.showUserPage(photosService.photoOwnerUid)
                        }

                        visible: !photosService.isAccountOwner
                    }
                }
                VkCoreText {
                    anchors {
                        left: parent.left
                        right: parent.right
                        leftMargin: 20
                        rightMargin: 20
                    }
                    text: photosService.albumTitle
                    horizontalAlignment: Text.AlignHCenter
                }
                VkCoreLabeledNumber {
                    anchors {
                        left: parent.left
                        right: parent.right
                        leftMargin: 20
                        rightMargin: 20
                    }

                    number: photoListModel.count
                    label: "фотографий"
                    label1: "фотография"
                    label234: "фотографии"

                    hideZero: true
                }
                VkCoreListElementDivider {
                    anchors {
                        leftMargin: 0
                        rightMargin: 0
                    }
                }
                Item {
                    id: photoHeaderDummy
                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    height: 10
                }
            }
            footer: Column {
                anchors {
                    left: parent ? parent.left : undefined
                    right: parent ? parent.right : undefined
                }
                spacing: 10

                VkCoreListElementDivider {
                    anchors {
                        leftMargin: 0
                        rightMargin: 0
                    }
                }

                VkCoreText {
                    anchors {
                        left: parent.left
                        right: parent.right
                        leftMargin: 20
                        rightMargin: 20
                    }

                    property string fullAlbumDesc: photosService.albumDesc + (photosService.albumDesc.length ? "<br/><br/>" : "") +
                                                   "<b>Создан: " + vkAppService.dateTimeToString(photosService.albumCreated, " в ", false, 0) +
                                                   "<br/>Изменен: " + vkAppService.dateTimeToString(photosService.albumUpdated, " в ", false, 0) + "</b>"

                    visible: photosService.isSystemAlbum
                    text: fullAlbumDesc
                    horizontalAlignment: Text.AlignHCenter
                }
            }
            visible: isPhotoListMode
        }
        ScrollDecorator {
            flickableItem: gridPhotoList
            visible: isPhotoListMode
        }
        visible: isPhotoListMode
    }
}
