// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import VkPages 1.0
import "../elements"

VkSubpageBase {

    property variant profileService
    property bool    isWallMode

    Connections {
        target: profileService
        onUserIdChanged: {
            actionBlock.isBlockVisible = true
            mainBlock.isBlockVisible = false
            contactsBlock.isBlockVisible = false
            educationBlock.isBlockVisible = false
            groupsBlock.isBlockVisible = false
            vkUserPageFlick.contentY = 0
        }
    }

    // signas
    signal showAccountOwnerPage()
    signal showWall()
    signal showFeed()

    loadingText: "Загрузка профиля"
    basePageService: profileService

    // ui settings
    property int    labelWidthCalc:     width * 0.33
    property int    labelWidthMin:      150
    property int    labelWidth:         labelWidthMin > labelWidthCalc ? labelWidthMin : labelWidthCalc
    property color  labelColor:         "#777777"
    property color  dividerColor:       "#45688E" //"#DAE1E8"
    property color  dividerTextColor:   "#45688E"

    // functions
    function relationString()
    {
        var relationNum = profileService.relation
        var isFemale    = profileService.sex === 1
        var havePartner = profileService.relPartId > 0
        var withWord = (vkAppService.isSomeCharInString(profileService.relPartName_ins, 0, "Сс") &&
                        vkAppService.isSomeCharInString(profileService.relPartName_ins, 1, "БВГДЖЗКЛМНПРСТФХЦЧШЩЪЬбвгджзклмнпрстфхцчшщъь")) ? " со " : " с "

        var rpAccLink = "<a href=\"" + profileService.relPartId + "\">" + profileService.relPartName_acc + "</a>"
        var rpInsLink = "<a href=\"" + profileService.relPartId + "\">" + profileService.relPartName_ins + "</a>"
        var rpAblLink = "<a href=\"" + profileService.relPartId + "\">" + profileService.relPartName_abl + "</a>"

        if (relationNum === 1) {
            return isFemale ? "не замужем" : "не женат"
        } else if (relationNum === 2) {
            return havePartner ? ("дружит" + withWord + rpInsLink) :
                                 (isFemale ? "есть друг" : "есть подруга")
        } else if (relationNum === 3) {
            var relNum3 = isFemale ? "помолвлена" : "помолвлен"
            // ins
            if (havePartner) {
                relNum3 += withWord + rpInsLink
            }
            return relNum3
        } else if (relationNum === 4) {
            var relNum4 = isFemale ? "замужем" : "женат"
            // ins : abl
            if (havePartner) {
                relNum4 += (isFemale ? " за " + rpInsLink : " на " + rpAblLink)
            }
            return relNum4
        } else if (relationNum === 5) {
            var relNum5 = "всё сложно"
            // ins
            if (havePartner) {
                relNum5 += withWord + rpInsLink
            }
            return relNum5
        } else if (relationNum === 6) {
            return "в активном поиске "
        } else if (relationNum === 7) {
            var toWord = (vkAppService.isSomeCharInString(profileService.relPartName_acc, 0, "Вв") &&
                          vkAppService.isSomeCharInString(profileService.relPartName_acc, 1, "БВГДЖЗКЛМНПРСТФХЦЧШЩЪЬбвгджзклмнпрстфхцчшщъь")) ? " во " : " в "
            var relNum7 = isFemale ? "влюблена" : "влюблён"
            if (havePartner) {
                relNum7 += toWord + rpAccLink
            }
            // acc
            return relNum7
        }

        return ""
    }

    Flickable {
        id: vkUserPageFlick
        contentWidth: vkUserPageContent.width
        contentHeight: vkUserPageContent.height
        flickableDirection: Flickable.VerticalFlick

        anchors.fill: parent

        Column {
            id: vkUserPageContent
            width: vkUserPageFlick.width

            spacing: 8

            VkCorePageHeader {
                id: profilePageHeader

                Button {
                    anchors {
                        left: parent.left
                        verticalCenter: parent.verticalCenter
                        leftMargin: 10
                    }

                    iconSource: profileService.isAccountOwner ? "../../icons/vk-feed.png" : "image://theme/icon-m-toolbar-home"
                    width: height
                    onClicked: profileService.isAccountOwner ? showFeed() : showAccountOwnerPage()
                }
                ButtonRow {
                    id: profilePageTypeSwitch
                    exclusive: false
                    anchors {
                        left: parent.left
                        right: parent.right
                        verticalCenter: parent.verticalCenter
                        leftMargin: 70
                        rightMargin: 70
                    }

                    Button {
                        id: profilePageTypePage
                        checked: !isWallMode
                        text: "Страница"
                    }
                    Button {
                        id: profilePageTypeWall
                        checked: false
                        text: "Стена"
                        onClicked: showWall()
                    }
                }
            }
            Row {
                id: mainUserInfo
                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: 20
                    rightMargin: 20
                }
                spacing: 16
                Column {
                    id: avatarAndRate
                    spacing: 8
                    width: (val_rate.width > val_avatar.width) ? val_rate.width : val_avatar.width
                    VkCoreImage {
                        id: val_avatar
                        imgSrc: profileService.photo_medium
                        imgLoader: "avatar"
                    }
                    VkProfileUserRate {
                        id: val_rate
                        rateValue: profileService.rate
                    }
                }
                Column {
                    id: personAndActivity
                    spacing: 8
                    width: mainUserInfo.width - mainUserInfo.spacing - avatarAndRate.width

                    Row {
                        id: personAndOnline
                        spacing: 16

                        Image {
                            id: val_online
                            source: "image://theme/icon-m-presence-online"
                            visible: profileService.online
                        }
                        VkCoreText {
                            id: personName
                            width: personAndActivity.width - (val_online.visible ? val_online.width + mainUserInfo.spacing : 0)
                            text: profileService.first_name + " " + profileService.nickname + " " + profileService.last_name
                            font.weight: Font.Bold
                            color: "#45688E"
                        }
                    }
                    VkCoreText {
                        anchors {
                            left: parent.left
                            right: parent.right
                        }
                        color: "#777777"
                        font.pixelSize: 16
                        visible: !profileService.online && profileService.online_time_valid
                        text: (profileService.sex > 0 ? profileService.sex === 1 ? "заходила " : "заходил " : "") + vkAppService.dateTimePassedToString(profileService.online_time, vkAppService.curDateTimeUpdated, " в ", false, 0)
                    }
                    Item {
                        id: activityBlock
                        anchors {
                            left: parent.left
                            right: parent.right
                        }
                        height: val_activity.text !== "" ? val_activity.height : 0
                        VkCoreText {
                            id: val_activity
                            anchors {
                                left: parent.left
                                right: parent.right
                            }
                            text: profileService.activity
                        }
                    }
                }
            }
            VkProfileActiveBlock {
                id: actionBlock
                isBlockVisible:         true
                headerDividerColor:     dividerColor
                headerDividerText:      "Действия"
                headerDividerTextColor: dividerTextColor
                content: Grid {
                    id: actionBlockContentGrid
                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    columns: appWindow.inPortrait ? 1 : 2
                    spacing: 8
                    property int defaultWidth: columns > 1 ? (width - spacing * (columns - 1)) / columns : width

                    Button {
                        width: actionBlockContentGrid.defaultWidth

                        text: profileService.isAccountOwner ? "Мои друзья" : "Друзья"
                        iconSource: "../../icons/vk-friends.png"
                        onClicked: mainPage.showOwnerFriendPage()
                        enabled: profileService.isAccountOwner
                    }
                    Button {
                        width: actionBlockContentGrid.defaultWidth

                        text: profileService.isAccountOwner ? "Мои сообщения" : "Диалог"
                        iconSource: "../../icons/vk-messages.png"
                        onClicked: profileService.isAccountOwner ? mainPage.showOwnerMessagePage() : mainPage.showDialogWith(profileService.userId)
                    }
                    Button {
                        width: actionBlockContentGrid.defaultWidth

                        text: profileService.isAccountOwner ? "Мои фотографии" : "Фотографии"
                        iconSource: "../../icons/vk-photos.png"
                        onClicked: profileService.isAccountOwner ? mainPage.showOwnerPhotoPage() : mainPage.showUserPhotoPage(profileService.userId)
                    }
                    Button {
                        width: actionBlockContentGrid.defaultWidth

                        text: profileService.isAccountOwner ? "Мои аудиозаписи" : "Аудиозаписи"
                        iconSource: "../../icons/vk-audio.png"
                        onClicked: profileService.isAccountOwner ? mainPage.showOwnerAudioPage() : mainPage.showUserAudioPage(profileService.userId)
                    }
                    Button {
                        width: actionBlockContentGrid.defaultWidth

                        text: profileService.isAccountOwner ? "Мои видеозаписи" : "Видеозаписи"
                        iconSource: "../../icons/vk-video.png"
                        onClicked: profileService.isAccountOwner ? mainPage.showOwnerVideoPage() : mainPage.showUserVideoPage(profileService.userId)
                    }
                }
            }
            VkProfileActiveBlock {
                id: mainBlock
                headerDividerColor:     dividerColor
                headerDividerText:      "Основная информация"
                headerDividerTextColor: dividerTextColor
                content: Grid {
                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    columns: 2
                    spacing: 6

                    VkCoreText {
                        id: label_sex
                        width: labelWidth
                        text: "Пол:"
                        color: labelColor
                    }
                    VkCoreText {
                        id: val_sex
                        width: parent.width - parent.spacing - labelWidth
                        text: !profileService.sex ? "не указано" : (profileService.sex === 1 ? "женский" : "мужской")
                    }
                    VkCoreText {
                        id: label_bdate
                        width: labelWidth
                        text: "День рождения:"
                        color: labelColor
                        visible: val_bdate.isValid
                    }
                    VkCoreDate {
                        id: val_bdate
                        width: parent.width - parent.spacing - labelWidth

                        nYear:  profileService.bdateYear
                        nMonth: profileService.bdateMonth
                        nDay:   profileService.bdateDay

                        visible: isValid
                    }
                    VkCoreText {
                        id: label_city
                        width: labelWidth
                        text: "Город:"
                        color: labelColor
                        visible: val_city.visible
                    }
                    VkCoreText {
                        id: val_city
                        width: parent.width - parent.spacing - labelWidth
                        text: profileService.city
                        visible: profileService.city !== ""
                    }
                    VkCoreText {
                        id: label_country
                        width: labelWidth
                        text: "Страна:"
                        color: labelColor
                        visible: val_country.visible
                    }
                    VkCoreText {
                        id: val_country
                        width: parent.width - parent.spacing - labelWidth
                        text: profileService.country
                        visible: profileService.country !== ""
                    }
                    VkCoreText {
                        id: label_relation
                        width: labelWidth
                        text: "Семейное положение:"
                        color: labelColor
                        visible: val_relation.visible
                    }
                    VkCoreText {
                        id: val_relation
                        width: parent.width - parent.spacing - labelWidth
                        text: relationString()
                        visible: text !== ""

                        onLinkActivated: mainPage.showUserPage(link)
                    }
                }
            }
            VkProfileActiveBlock {
                id: contactsBlock
                headerDividerColor:     dividerColor
                headerDividerText:      "Контактная информация"
                headerDividerTextColor: dividerTextColor
                visible: val_mobile_phone.isValid || val_home_phone.isValid
                content: Grid {
                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    columns: 2
                    spacing: 6

                    VkCoreText {
                        id: label_mobile_phone
                        width: labelWidth
                        text: "Моб. телефон:"
                        color: labelColor
                        visible: val_mobile_phone.isValid
                    }
                    VkCoreText {
                        id: val_mobile_phone
                        width: parent.width - parent.spacing - labelWidth
                        text: profileService.mobile_phone
                        property bool isValid: text !== ""
                        visible: isValid
                    }
                    VkCoreText {
                        id: label_home_phone
                        width: labelWidth
                        text: "Дом. телефон:"
                        color: labelColor
                        visible: val_home_phone.isValid
                    }
                    VkCoreText {
                        id: val_home_phone
                        width: parent.width - parent.spacing - labelWidth
                        text: profileService.home_phone
                        property bool isValid: text !== ""
                        visible: isValid
                    }
                }
            }
            VkProfileActiveBlock {
                id: educationBlock
                headerDividerColor:     dividerColor
                headerDividerText:      "Образование"
                headerDividerTextColor: dividerTextColor
                visible: val_university_name.isValid || val_faculty_name.isValid
                content: Grid {
                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    columns: 2
                    spacing: 6

                    VkCoreText {
                        id: label_university_name
                        width: labelWidth
                        text: "Вуз:"
                        color: labelColor
                        visible: val_university_name.isValid
                    }
                    VkCoreText {
                        id: val_university_name
                        property bool isGradValid: profileService.graduation !== "" && profileService.graduation !== "0"
                        width: parent.width - parent.spacing - labelWidth
                        text: isGradValid ? profileService.university_name + " '" + profileService.graduation : profileService.university_name
                        property bool isValid: profileService.university_name !== "" || isGradValid
                        visible: isValid
                    }
                    VkCoreText {
                        id: label_faculty_name
                        width: labelWidth
                        text: "Факультет:"
                        color: labelColor
                        visible: val_faculty_name.isValid
                    }
                    VkCoreText {
                        id: val_faculty_name
                        width: parent.width - parent.spacing - labelWidth
                        text: profileService.faculty_name
                        property bool isValid: text !== ""
                        visible: isValid
                    }
                }
            }
            VkProfileActiveBlock {
                id: groupsBlock
                headerDividerColor:     dividerColor
                headerDividerText:      "Группы"
                headerDividerTextColor: dividerTextColor
                visible: false
                content: VkCoreText {
                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    text: "В разработке"
                    color: labelColor
                }
            }
            Item {
                id: dummy
                anchors {
                    left: parent.left
                    right: parent.right
                }
                height: 20
            }
        }
    }
}
