// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import VkPages 1.0
import "../elements"

VkSubpageBase {
    id: vkSubpageVideo

    property variant videoService
    loadingText: "Загрузка видеозаписей"
    basePageService: videoService

    property bool searchResultView: false
    property string commonTitle: videoService.isAccountOwner ? "Мои видеозаписи" : "Видеозаписи " + videoService.videoOwnerFName

    // signas
    signal showAccountOwnerVideo()
    signal showVideoItem(int idx)

    property alias videoListModel: videoList.model
    property bool isVideoListLoading: videoService.listLoading
    property int videoServerCount: videoService.listServerCount
    property int videoServerOffset: videoService.listServerOffset

    // internal
    property int  videoListModelCount: videoListModel.count

    Item {
        anchors {
            fill: parent
            leftMargin: 20
            rightMargin: 20
        }
        VkCoreText {
            id: emptyListLabel
            anchors.fill: parent
            anchors.topMargin: searchResultView ? parent.height * 0.25 : 0

            property bool labelEnabled: true

            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text: searchResultView ? "Видеозаписи не найдены" : "Нет видеозаписей"
            font.bold: true
            font.pixelSize: 60
            color: "darkgrey"
            visible: (labelEnabled || searchResultView) && ((videoServerCount === 0) && !isVideoListLoading)
        }
    }

    // video list
    Item {
        anchors.fill: parent
        ListView {
            id: videoList
            spacing: 10
            anchors.fill: parent
            delegate: VkVideoListItem {
                anchors {
                    leftMargin: 20
                    rightMargin: 20
                }

                onItemClicked: {
                    //videoPlayer.play()
                    showVideoItem(index)
                }
            }

            section.property: "searchType"
            section.criteria: ViewSection.FullString
            section.delegate: Column {
                width: parent.width

                VkCoreListElementDivider {
                    anchors {
                        leftMargin: 0
                        rightMargin: 0
                    }
                }
                VkCoreText {
                    anchors {
                        left: parent.left
                        right: parent.right
                        leftMargin: 10
                        rightMargin: 10
                    }
                    text: section === "local" ? commonTitle : "Результаты поиска"
                    font.bold: true
                    font.pixelSize: 32
                }
                VkCoreListElementDivider {
                    anchors {
                        leftMargin: 0
                        rightMargin: 0
                    }
                }
            }

            header: Column {
                anchors {
                    left: parent ? parent.left : undefined
                    right: parent ? parent.right : undefined
                }
                spacing: 10
                VkCorePageHeader {
                    headerLabelText: commonTitle

                    VkCoreAvatar {
                        anchors {
                            right: parent.right
                            verticalCenter: parent.verticalCenter
                            rightMargin: 10
                        }

                        imgSrc: videoService.videoOwnerAvatar
                        online: videoService.videoOwnerOnline

                        VkCoreSelectionArea {
                            anchors.fill: parent
                            onClicked: mainPage.showUserPage(videoService.userId)
                        }

                        visible: !videoService.isAccountOwner
                    }
                }
                Item {
                    id: buttonPlaceholder
                    // fix header height change artefacts

                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    height: !videoService.isAccountOwner ? btnToOwherVideo.height : 0

                    Button {
                        id: btnToOwherVideo
                        anchors {
                            left: parent.left
                            right: parent.right
                            leftMargin: 20
                            rightMargin: 20
                        }

                        text: "К моим видеозаписям"
                        visible: !videoService.isAccountOwner
                        onClicked: showAccountOwnerVideo()
                    }
                }
                VkCoreLabeledNumber {
                    anchors {
                        left: parent.left
                        right: parent.right
                        leftMargin: 20
                        rightMargin: 20
                    }

                    property bool usePrefix: !searchResultView && (videoServerOffset < videoServerCount)

                    number: searchResultView ? videoListModelCount : (videoServerCount >= 0 ? videoServerCount : 0)
                    prefix: usePrefix ? (videoListModelCount + " из ") : ""
                    label: "видеозаписей"
                    label1: usePrefix ? "видеозаписи" : "видеозапись"
                    label234: usePrefix ? "видеозаписей" : "видеозаписи"

                    hideZero: true
                }
                VkCoreListElementDivider {
                    anchors {
                        leftMargin: 0
                        rightMargin: 0
                    }
                }
                Item {
                    id: headerDummy
                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    height: 10
                }
                VkCoreListSearch {
                    id: videoSearch
                    anchors {
                        leftMargin: 20
                        rightMargin: 20
                    }

                    listElement: videoList
                    searchBusy: videoService.videoSearchInProcess

                    onSearchRequest: {
                        // start new search here
                        searchResultView = false
                        videoService.searchVideo(request, isGlobal)
                        searchResultView = true
                    }
                    onResetSearch: searchResultView = false
                    Binding {
                        target: emptyListLabel
                        property: "labelEnabled"
                        value: !videoSearch.searchPanelOpen
                    }
                }
            }
            footer: VkCoreListFooter {
                anchors {
                    leftMargin: 20
                    rightMargin: 20
                }

                needInitialLoad: false
                isLoading: isVideoListLoading
                showDivider: false
                onMoreClicked: videoService.getMoreList(100)

                visible: !searchResultView && (videoServerCount < 0 || videoServerOffset < videoServerCount)
            }
        }
        ScrollDecorator {
            flickableItem: videoList
        }
    }
}
