// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1
import VkPages 1.0
import "../elements"

Item {
    id: vkSubpageVideoItemView

    property variant videoService

    property alias commentListModel: commentList.model
    property bool isCommentListLoading: false//videoService.commentsLoading
    property int commentServerCount: -1 //videoService.commentServerCount
    property int commentServerOffset: 0 //videoService.commentServerOffset

    // functions and signals
    function setVideoItem(videoListModel, idx, listModelOwn, fromSearch)
    {
        m_title         = videoListModel.data(idx, "title")
        m_description   = videoListModel.data(idx, "description")
        m_duration      = videoListModel.data(idx, "duration")
        m_image         = videoListModel.data(idx, "image")
        m_player        = videoListModel.data(idx, "player")
        m_vid           = videoListModel.data(idx, "vid")
        m_owner_id      = videoListModel.data(idx, "owner_id")
        m_canAddItem    = videoListModel.data(idx, "canAddItem")
        m_canRemoveItem = videoListModel.data(idx, "canRemoveItem")
        m_itemBusy      = videoListModel.data(idx, "addRemoveInProgress")
        m_listIdx       = idx
        m_listModelOwn  = listModelOwn
        m_fromSearch    = fromSearch
        m_externalVid   = false
        // delegated
        m_likes_count   = videoListModel.data(idx, "likes_count")
        m_likes_user_likes = videoListModel.data(idx, "likes_user_likes")
        m_likes_can_like = videoListModel.data(idx, "likes_can_like")
        m_likes_busy    = videoListModel.data(idx, "likes_busy")
        m_likes_valid   = videoListModel.data(idx, "likes_valid")

        if (!m_likes_valid) {
            videoService.videoGetLikes(m_listIdx, m_owner_id, m_vid, m_fromSearch, m_externalVid);
        }
    }
    function setVideoItemFromData(vid, owner_id, title, description, duration, image, player, likes_count, likes_user_likes, likes_can_like, likes_busy, likes_valid)
    {
        m_title         = title
        m_description   = description
        m_duration      = duration
        m_image         = image
        m_player        = player
        m_vid           = vid
        m_owner_id      = owner_id
        m_canAddItem    = false
        m_canRemoveItem = false
        m_itemBusy      = false
        m_listIdx       = 0
        m_listModelOwn  = false
        m_fromSearch    = false
        m_externalVid   = true
        // delegated
        m_likes_count   = likes_count
        m_likes_user_likes = likes_user_likes
        m_likes_can_like = likes_can_like
        m_likes_busy    = likes_busy
        m_likes_valid   = likes_valid

        if (!m_likes_valid) {
            videoService.videoGetLikes(m_listIdx, m_owner_id, m_vid, m_fromSearch, m_externalVid);
        }
    }
    function videoCanAddChanged(videoOwnerId, videoItemId, canAddItem)
    {
        if (videoOwnerId !== m_owner_id || videoItemId !== m_vid) {
            return;
        }
        m_canAddItem = canAddItem
    }
    function videoBusyChanged(videoOwnerId, videoItemId, itemBusy)
    {
        if (videoOwnerId !== m_owner_id || videoItemId !== m_vid) {
            return;
        }
        m_itemBusy = itemBusy
    }
    function videoRemoved(idx, videoOwnerId, videoItemId)
    {
        if (idx !== m_listIdx || videoOwnerId !== m_owner_id || videoItemId !== m_vid) {
            return;
        }
        leaveFullViewClicked()
    }
    function videoLikeBusyChanged(videoOwnerId, videoItemId, itemBusy)
    {
        if (videoOwnerId !== m_owner_id || videoItemId !== m_vid) {
            return;
        }
        m_likes_busy = itemBusy
    }
    function videoLikeInfoChanged(videoOwnerId, videoItemId, likes_count, likes_user_likes, likes_can_like)
    {
        if (videoOwnerId !== m_owner_id || videoItemId !== m_vid) {
            return;
        }
        m_likes_count   = likes_count
        m_likes_user_likes = likes_user_likes
        m_likes_can_like = likes_can_like
        m_likes_valid   = true

    }
    function moreCommentsClicked()
    {
        //videoService.getMoreComments(20)
    }
    function reloadCommentsClicked()
    {
        //videoService.refreshComments()
    }
    signal leaveFullViewClicked()
    signal addVideoItem(bool listModelOwn, int idx, string videoOwnerId, int videoItemId, bool fromSearch)      // fix negative int id
    signal removeVideoItem(bool listModelOwn, int idx, string videoOwnerId, int videoItemId)                    // fix negative int id

    // internal
    property int  commentListModelCount: 0//commentListModel.count
    property bool needInitialCommentLoading: commentListModelCount === 0

    property string m_title:        ""
    property string m_description:  ""
    property int    m_duration:     0
    property string m_image:        ""
    property string m_player:       ""
    property int    m_vid:          0
    property string m_owner_id:     "0"         // fix negative int id
    property bool   m_canAddItem:   false
    property bool   m_canRemoveItem:false
    property bool   m_itemBusy:     false
    property int    m_listIdx:      0
    property bool   m_listModelOwn: false
    property bool   m_fromSearch:   false
    property bool   m_externalVid:  false
    // delegated
    property int    m_likes_count: 0
    property bool   m_likes_user_likes: false
    property bool   m_likes_can_like: false
    property bool   m_likes_busy: false
    property bool   m_likes_valid: false

    // dialog
    QueryDialog {
        id: deleteVideoQueryDialog

        icon: "image://theme/icon-m-transfer-error"
        titleText: "Удалить видеозапись?"
        message: "Вы действительно хотите удалить видеозапись?\n"
                 + "Видеозапись будет удалена без возможности восстановления."
        acceptButtonText: "Удалить"
        rejectButtonText: "Отмена"

        onAccepted: {
            removeVideoItem(m_listModelOwn, m_listIdx, m_owner_id, m_vid)
        }
    }

    // comments list; video item displayed in list header
    ListView {
        id: commentList
        anchors.fill: parent
        delegate: Item {
            anchors {
                left: parent.left
                right: parent.right
                leftMargin: 20
                rightMargin: 20
            }
            height: tmpLabel.height
            VkCoreText {
                id: tmpLabel
                anchors {
                    left: parent.left
                    right: parent.right
                }
                horizontalAlignment: Text.AlignHCenter
                text: name
                font.bold: true
                font.pixelSize: 30
                color: "darkgrey"
            }
        }
        header: Column {
            anchors {
                left: parent ? parent.left : undefined
                right: parent ? parent.right : undefined
            }
            spacing: 10
            VkCorePageHeader {
                id: commentsPageHeader

                ListButton {
                    id: btnBackToVideos
                    anchors {
                        left: parent.left
                        verticalCenter: parent.verticalCenter
                        leftMargin: 20
                    }
                    text: isVideoPlayerExternal ? "Мои видеозаписи" : "Все видеозаписи"
                    onClicked: leaveFullViewClicked()
                }

                VkCoreAvatar {
                    id: val_avatar
                    anchors {
                        right: parent.right
                        verticalCenter: parent.verticalCenter
                        rightMargin: 10
                    }

                    imgSrc: videoService.videoOwnerAvatar
                    online: videoService.videoOwnerOnline

                    VkCoreSelectionArea {
                        anchors.fill: parent
                        onClicked: mainPage.showUserPage(videoService.userId)
                    }

                    visible: !videoService.isAccountOwner && !isVideoPlayerExternal
                }
            }
            VkCoreText {
                id: videoItemViewText
                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: 20
                    rightMargin: 20
                }
                text: (isVideoPlayerExternal || m_fromSearch) ? "Видеозапись" : (videoService.isAccountOwner ? "Моя видеозапись" : "Видеозапись " + videoService.videoOwnerFName)
            }
            VkCoreListElementDivider {
                anchors {
                    leftMargin: 0
                    rightMargin: 0
                }
            }
            // video item
            VkCoreImage {
                id: videoItem
                anchors.horizontalCenter: parent.horizontalCenter
                imgSrc:    m_image
                imgLoader: "photo"

                Image {
                    id: videoItemPic
                    anchors.centerIn: parent
                    source: "../../icons/vk-videoclip.png"
                }

                Rectangle {
                    id: videoTimeBar
                    anchors {
                        left: parent.left
                        right: parent.right
                        bottom: parent.bottom
                    }
                    height: videoInfoTime.height
                    color: "#A0000000"

                    VkCoreText {
                        id: videoInfoTime
                        anchors {
                            right: parent.right
                            bottom: parent.bottom
                            rightMargin: 5
                        }
                        text: vkAppService.getTimeFromMSec(m_duration * 1000)
                        font.pixelSize: 14
                        color: "white"
                        wrapMode: Text.NoWrap
                    }
                }

                VkCoreSelectionArea {
                    anchors.fill: parent
                    onClicked: Qt.openUrlExternally(m_player)
                }
            }
            Item {
                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: 20
                    rightMargin: 20
                }
                height: actionButton.height

                ListButton {
                    id: actionButton
                    anchors {
                        verticalCenter: parent.verticalCenter
                        left: parent.left
                    }
                    property bool actionDelete: m_canRemoveItem
                    text: actionDelete ? "Удалить" : "Добавить"
                    iconSource: actionDelete ? (enabled ? "image://theme/icon-m-toolbar-delete" : "image://theme/icon-m-toolbar-delete-dimmed")
                                             : (enabled ? "image://theme/icon-m-toolbar-add" : "image://theme/icon-m-toolbar-add-dimmed")
                    enabled: !m_itemBusy && (actionDelete ? m_canRemoveItem : m_canAddItem)

                    onClicked: if (actionDelete) {
                                   deleteVideoQueryDialog.open()
                               } else {
                                   addVideoItem(m_listModelOwn, m_listIdx, m_owner_id, m_vid, m_fromSearch)
                               }
                }
                BusyIndicator {
                    anchors {
                        left: actionButton.right
                        leftMargin: 10
                        verticalCenter: parent.verticalCenter
                    }
                    visible: m_itemBusy
                    running: m_itemBusy
                }
                VkCoreLikeControlShort {
                    id: likeCtrl
                    anchors {
                        verticalCenter: parent.verticalCenter
                        right: parent.right
                    }
                    visible: m_likes_valid

                    property int likes_count: m_likes_count
                    property bool likes_user_likes: m_likes_user_likes
                    property bool likes_can_like: m_likes_can_like
                    property bool likes_busy: m_likes_busy

                    onLikeClicked: videoService.videoAddLike(m_listIdx, m_owner_id, m_vid, m_fromSearch, m_externalVid)
                    onDislikeClicked: videoService.videoDeleteLike(m_listIdx, m_owner_id, m_vid, m_fromSearch, m_externalVid)
                }
                BusyIndicator {
                    anchors {
                        right: likeCtrl.right
                        verticalCenter: parent.verticalCenter
                    }
                    visible: !m_likes_valid
                    running: !m_likes_valid
                }
            }
            Item {
                id: videoInfo
                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: 20
                    rightMargin: 20
                }
                height: videoInfoTitle.height + videoInfoDesc.height + videoInfoDesc.anchors.topMargin

                VkCoreText {
                    id: videoInfoTitle
                    anchors {
                        left: parent.left
                        right: parent.right
                        top: parent.top
                    }
                    text: m_title
                    font.bold: true
                    font.pixelSize: 16
                }
                VkCoreText {
                    id: videoInfoDesc
                    anchors {
                        left: parent.left
                        right: parent.right
                        top: videoInfoTitle.bottom
                        topMargin: 10
                    }
                    text: m_description
                    font.pixelSize: 15
                    clip: true
                }
            }

            VkCoreListElementDivider {
                anchors {
                    leftMargin: 0
                    rightMargin: 0
                }
            }
            Item {
                anchors {
                    left: parent.left
                    right: parent.right
                }
                height: btnReload.height
                VkCoreLabeledNumber {
                    anchors {
                        left: parent.left
                        right: btnReload.left
                        verticalCenter: parent.verticalCenter
                        leftMargin: 20
                        rightMargin: 20
                    }

                    property bool usePrefix: false //commentServerOffset < commentServerCount

                    number: 0
                    prefix: usePrefix ? (commentListModelCount + " из ") : ""
                    label: "комментариев"
                    label1: usePrefix ? "комментария" : "комментарий"
                    label234: usePrefix ? "комментариев" : "комментария"
                }
                Button {
                    id: btnReload
                    anchors {
                        right: parent.right
                        top: parent.top
                        rightMargin: 20
                    }
                    iconSource: "image://theme/icon-m-toolbar-refresh"
                    width: height
                    onClicked: reloadCommentsClicked()
                }
            }
            VkCoreListElementDivider {
                anchors {
                    leftMargin: 0
                    rightMargin: 0
                }
            }
            Item {
                id: dummy
                anchors {
                    left: parent.left
                    right: parent.right
                }
                height: 10
            }
        }
    }
    ScrollDecorator {
        flickableItem: commentList
    }
}
