// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import VkPages 1.0
import "../elements"

Item {
    id: vkSubpageWall

    property variant wallService
    property bool    isWallMode

    property alias wallListModel: wallMessages.model
    property bool isWallListLoading: wallService.wallLoading
    property int wallServerCount: wallService.wallServerCount
    property int wallServerOffset: wallService.wallServerOffset
    property string senderName: ""
    property string senderAvatar: ""

    // functions and signals
    function moreWallClicked()
    {
        wallService.getMoreWall(20)
    }
    function reloadWallClicked()
    {
        wallService.refreshWall()
    }
    function setIndex(idx) {
        wallMessages.positionViewAtIndex(idx, ListView.Beginning);
//        wallMessages.currentIndex = idx;
//        wallMessages.highlightFollowsCurrentItem = true;
//        wallMessages.highlightMoveDuration = 150;
//        wallMessages.highlightRangeMode = ListView.StrictlyEnforceRange;
    }
    signal leaveWallClicked()
    signal showAccountOwnerPage()
    signal showFeed()
    signal viewWallItem(int idx)

    // internal
    property int  wallListModelCount: wallListModel.count
    property bool needInitialWallLoading: wallListModelCount === 0


    // empty list label
    VkCoreText {
        id: emptyListLabel
        anchors {
            fill: parent
            leftMargin: 20
            rightMargin: 20
        }

        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        text: "Нет записей"
        font.bold: true
        font.pixelSize: 60
        color: "darkgrey"
        visible: (wallServerCount === 0) && !isWallListLoading
    }
    ListView {
        id: wallMessages
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            bottom: sendMsgRect.top
        }
        pressDelay: 100
        cacheBuffer: 400
        delegate: VkWallListItem {
            onViewWallItem: vkSubpageWall.viewWallItem(idx)
        }
        header: Column {
            anchors {
                left: parent ? parent.left : undefined
                right: parent ? parent.right : undefined
            }
            spacing: 10
            VkCorePageHeader {
                id: wallPageHeader
                Button {
                    anchors {
                        left: parent.left
                        verticalCenter: parent.verticalCenter
                        leftMargin: 10
                    }

                    iconSource: wallService.isAccountOwner ? "../../icons/vk-feed.png" : "image://theme/icon-m-toolbar-home"
                    width: height
                    onClicked: wallService.isAccountOwner ? showFeed() : showAccountOwnerPage()
                }

                ButtonRow {
                    id: profilePageTypeSwitch
                    exclusive: false
                    anchors {
                        left: parent.left
                        right: parent.right
                        verticalCenter: parent.verticalCenter
                        leftMargin: 70
                        rightMargin: 70
                    }

                    Button {
                        id: profilePageTypePage
                        checked: false
                        text: "Страница"
                        onClicked: leaveWallClicked()
                    }
                    Button {
                        id: profilePageTypeWall
                        checked: isWallMode
                        text: "Стена"
                    }
                }

                VkCoreAvatar {
                    id: val_avatar
                    anchors {
                        right: parent.right
                        verticalCenter: parent.verticalCenter
                        rightMargin: 10
                    }

                    imgSrc: wallService.photo_rec
                    online: wallService.online

                    visible: !wallService.isAccountOwner
                }
            }
            VkCoreText {
                id: wallHeaderText
                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: 20
                    rightMargin: 10
                }
                text: "Стена " + wallService.first_name_gen
                visible: !wallService.isAccountOwner
            }
            Item {
                anchors {
                    left: parent.left
                    right: parent.right
                }
                height: btnReload.height
                VkCoreLabeledNumber {
                    anchors {
                        left: parent.left
                        right: btnReload.left
                        verticalCenter: parent.verticalCenter
                        leftMargin: 20
                        rightMargin: 20
                    }

                    property bool usePrefix: wallServerOffset < wallServerCount

                    number: wallServerCount >= 0 ? wallServerCount : 0
                    prefix: usePrefix ? (wallListModelCount + " из ") : ""
                    label: "записей"
                    label1: usePrefix ? "записи" : "запись"
                    label234: usePrefix ? "записей" : "записи"
                    hideZero: true
                }
                Button {
                    id: btnReload
                    anchors {
                        right: parent.right
                        top: parent.top
                        rightMargin: 20
                    }
                    iconSource: "image://theme/icon-m-toolbar-refresh"
                    width: height
                    onClicked: reloadWallClicked()
                }
            }
            VkCoreListElementDivider {
                anchors {
                    leftMargin: 0
                    rightMargin: 0
                }
            }
            Item {
                id: dummy
                anchors {
                    left: parent.left
                    right: parent.right
                }
                height: 10
            }
        }
        footer: VkCoreListFooter {
            anchors {
                leftMargin: 20
                rightMargin: 20
            }

            needInitialLoad: (wallService.status === VkPageService.Ready && vkSubpageWall.visible) ? needInitialWallLoading : false
            isLoading: isWallListLoading
            showDivider: false
            onMoreClicked: moreWallClicked()

            visible: wallServerCount < 0 || wallServerOffset < wallServerCount
        }
    }
    ScrollDecorator {
        flickableItem: wallMessages
    }

    // send wall message
    Rectangle {
        id: sendMsgRect
        anchors {
            left: parent.left
            right: parent.right
            bottom: parent.bottom
        }
        height: wallService.can_post ? sendMsgInput.implicitHeight : 0
        visible: wallService.can_post

        color: "lightgray"

        states: [
            State {
                name: "maximized"
                when: sendMsgInput.activeFocus
                PropertyChanges { target: sendMsgRect; height: visible ? sendMsgInput.height + sendMsgColumn.spacing + sendMsgButton.height : 0 }
            },
            State {
                name: "minimized"
                when: !sendMsgInput.activeFocus
                PropertyChanges { target: sendMsgRect; height: visible ? sendMsgInput.implicitHeight : 0 }
            }
        ]

        state: "minimized"

        transitions: [
            Transition {
                to: "maximized"
                NumberAnimation { properties: "height"; easing.type: Easing.OutCubic; duration: 500 }
            },
            Transition {
                to: "minimized"
                NumberAnimation { properties: "height"; easing.type: Easing.InCubic; duration: 500 }
            }
        ]

        Column {
            id: sendMsgColumn
            spacing: 2
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }

            TextArea {
                id: sendMsgInput
                anchors {left: parent.left; right: parent.right}
                placeholderText: wallService.isAccountOwner ? "Что у меня нового?" : "Напишите сообщение"
                textFormat: TextEdit.PlainText
                wrapMode: TextEdit.Wrap
            }
            Button {
                id: sendMsgButton
                anchors {right: parent.right}
                text: "Отправить"
                onClicked: {
                    wallService.wallSendPost(senderName, senderAvatar, sendMsgInput.text)
                    sendMsgInput.text = ""
                }
                enabled: sendMsgInput.text.length > 0
            }
        }
    }
}
