// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1
import VkPages 1.0
import "../elements"

Item {
    id: vkSubpageWallItemView

    property variant wallService

    property alias wallItemViewerModel: wallItemViewer.model
    property alias commentListModel: commentList.model
    property bool isCommentListLoading: commentListModel.isLoading
    property int commentServerCount: commentListModel.serverCount
    property int commentServerOffset: commentListModel.serverOffset
    property string senderName: ""
    property string senderAvatar: ""

    // functions and signals
    function moreCommentsClicked()
    {
        commentListModel.getMoreList(20)
    }
    function reloadCommentsClicked()
    {
        commentListModel.refreshList()
    }
    signal setWallItemIndex(int idx)
    signal leaveFullViewClicked(int idxBack)

    // internal
    property int  commentListModelCount: commentListModel.count
    property bool needInitialCommentLoading: commentListModel.needAutoLoad


    VkCoreAreaSwitcher {
        id: commentAreaSwitcher
        anchors.fill: parent

        property int itemLabelHeight: 80
        property int commentLabelHeight: 0
        property string commentLabelText: "Комментарии"
        property bool isCommentsAvailable: wallItemViewer.currentItem ? wallItemViewer.currentItem.isCommentsAvailable : false

        area1LabelHeight: itemLabelHeight
        area2LabelHeight: isCommentsAvailable ? commentLabelHeight : 0
        area1LabelText: "Комментарии к записи"
        area2LabelText: commentLabelText

        Flickable {
            id: flickableItem
            anchors.fill: parent

            contentWidth: flickableContent.width
            contentHeight: flickableContent.height

            flickableDirection: Flickable.VerticalFlick

            function returnToTop()
            {
                contentItem.y = 0
            }

            Column {
                id: flickableContent
                width: flickableItem.width
                spacing: 10

                VkCorePageHeader {
                    id: commentsPageHeader
                    //headerLabelText: "Запись на стене"

                    ListButton {
                        id: btnBackToWall
                        anchors {
                            left: parent.left
                            verticalCenter: parent.verticalCenter
                            leftMargin: 20
                        }
                        text: "Все записи"
                        onClicked: leaveFullViewClicked(wallItemViewer.currentIndex)
                    }

                    VkCoreAvatar {
                        id: val_avatar
                        anchors {
                            right: parent.right
                            verticalCenter: parent.verticalCenter
                            rightMargin: 10
                        }

                        imgSrc: wallService.photo_rec
                        online: wallService.online

                        VkCoreSelectionArea {
                            anchors.fill: parent
                            onClicked: mainPage.showUserPage(wallService.userId)
                        }

                        visible: !wallService.isAccountOwner
                    }
                }
                VkCoreText {
                    id: wallItemViewText
                    anchors {
                        left: parent.left
                        right: parent.right
                        leftMargin: 20
                        rightMargin: 20
                    }
                    text: wallService.isAccountOwner ? "Запись на моей стене" : "Запись на стене " + wallService.first_name_gen
                }
                VkCoreListElementDivider {
                    id: wallItemViewDivider
                    anchors {
                        leftMargin: 0
                        rightMargin: 0
                    }
                }
                // wall item
                ListView {
                    id: wallItemViewer
                    anchors {
                        left: parent.left
                        right: parent.right
                        leftMargin: 20
                        rightMargin: 20
                    }

                    delegate: VkWallListItem {
                        isBriefView: false
                        fullViewWidth: wallItemViewer.width

                        onWallAttNeedFullInfo: {
                            wallService.wallAttNeedInfo(itemIdx)
                        }
                        onWallAttPhotoClicked: {
                            wallService.wallPrepareAttPhotos(itemIdx, photoIdx, pid, owner_id)
                            mainPage.showExternalViewPhotoPage(photoIdx)
                        }
                        onWallAttVideoClicked: {
                            mainPage.showExternalViewVideoPage(vid, owner_id, title, description, duration, image, player, v_likes_count, v_likes_user_likes, v_likes_can_like, v_likes_busy, v_likes_valid)
                        }
                        onWallAttAudioClicked: {
                            wallService.wallPrepareAttAudio(itemIdx, audioIdx, aid, owner_id)
                            mainPage.showExternalViewAudioPage(audioIdx, true, true)
                        }
                        onWallAttGraffitiClicked: {
                            wallService.wallPrepareAttGraffiti(itemIdx, graffitiIdx, gid, owner_id)
                            mainPage.showExternalViewPhotoPage(graffitiIdx)
                        }

                        // internal
                        property int totalCommentsCount   : comments_count
                        property bool userCanPostComment  : comments_can_post
                        property string itemOwner_id      : to_id               // fix negative int id
                        property string itemPost_id       : id                  // fix negative int id
                        property bool isCommentsAvailable : true    //type === "post"
                    }
                    property int currentItemHeight : wallItemViewer.currentItem ? wallItemViewer.currentItem.height : 0
                    property int minItemHeight : flickableItem.height - commentsPageHeader.height
                                                                      - wallItemViewText.height
                                                                      - wallItemViewDivider.height
                                                                      - commentsPageDummy.height
                                                                      - flickableContent.spacing * 4 + 1
                    height: currentItemHeight > minItemHeight ? currentItemHeight : minItemHeight

                    orientation: ListView.Horizontal
                    snapMode: ListView.SnapOneItem

                    // ensure current item change when flick list
                    highlightFollowsCurrentItem: true
                    highlightMoveDuration: 150
                    highlightRangeMode: ListView.StrictlyEnforceRange

                    Connections {
                        target: vkSubpageWallItemView
                        onSetWallItemIndex: {
                            commentAreaSwitcher.resetAreaState();
                            wallItemViewer.positionViewAtIndex(idx, ListView.Center);
                            wallItemViewer.currentIndex = idx;
                            wallItemViewer.highlightFollowsCurrentItem = true;
                            wallItemViewer.highlightMoveDuration = 150;
                            wallItemViewer.highlightRangeMode = ListView.StrictlyEnforceRange;
                        }
                    }
                    onCurrentItemChanged: {
                        //console.log("onCurrentItemChanged")
                        flickableItem.returnToTop()
                        if (currentItem) {
                            commentListModel.initComments(currentItem.itemOwner_id, currentItem.itemPost_id)
                        }
                    }
                }
                Item {
                    id: commentsPageDummy
                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    height: 10
                }
            }
        }
        Item {
            id: commentsArea
            anchors.fill: parent

            property bool isActive: parent ? parent.isAreaActive : false

            // comments list
            ListView {
                id: commentList
                anchors {
                    left: parent.left
                    right: parent.right
                    top: parent.top
                    bottom: sendMsgRect.top
                }
                delegate: VkCommentListItem {
                }
                header: Column {
                    id: commentHead
                    anchors {
                        left: parent ? parent.left : undefined
                        right: parent ? parent.right : undefined
                    }
                    spacing: 10
                    Binding {
                        target: commentAreaSwitcher
                        property: "commentLabelHeight"
                        value: commentHead.height
                    }
                    Item {
                        id: dummy1
                        anchors {
                            left: parent.left
                            right: parent.right
                        }
                        height: 1
                    }
                    Item {
                        anchors {
                            left: parent.left
                            right: parent.right
                        }
                        height: btnReload.height
                        VkCoreLabeledNumber {
                            id: commentCountLabel
                            anchors {
                                left: parent.left
                                right: btnReload.left
                                verticalCenter: parent.verticalCenter
                                leftMargin: 20
                                rightMargin: 20
                            }

                            property bool usePrefix: commentServerOffset < commentServerCount
                            property int totalCount: wallItemViewer.currentItem ? wallItemViewer.currentItem.totalCommentsCount : 0
                            property int loadedCount: commentServerCount >= 0 ? commentServerCount : 0

                            number: needInitialCommentLoading ? totalCount : loadedCount
                            prefix: usePrefix ? (commentListModelCount + " из ") : ""
                            label: "комментариев"
                            label1: usePrefix ? "комментария" : "комментарий"
                            label234: usePrefix ? "комментариев" : "комментария"

                            Binding {
                                target: commentAreaSwitcher
                                property: "commentLabelText"
                                value: commentCountLabel.text
                            }
                        }
                        Button {
                            id: btnReload
                            anchors {
                                right: parent.right
                                top: parent.top
                                rightMargin: 20
                            }
                            iconSource: "image://theme/icon-m-toolbar-refresh"
                            width: height
                            onClicked: reloadCommentsClicked()
                        }
                    }
                    VkCoreListElementDivider {
                        anchors {
                            leftMargin: 0
                            rightMargin: 0
                        }
                    }
                    Item {
                        id: dummy2
                        anchors {
                            left: parent.left
                            right: parent.right
                        }
                        height: 1
                    }
                }
                footer: VkCoreListFooter {
                    anchors {
                        leftMargin: 20
                        rightMargin: 20
                    }

                    needInitialLoad: commentsArea.isActive ? needInitialCommentLoading : false
                    isLoading: isCommentListLoading
                    showDivider: false
                    onMoreClicked: moreCommentsClicked()

                    visible: commentServerCount < 0 || commentServerOffset < commentServerCount
                }
            }
            ScrollDecorator {
                flickableItem: commentList
            }

            // send wall item comment
            Rectangle {
                id: sendMsgRect
                anchors {
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                }
                property bool canPost: wallItemViewer.currentItem ? wallItemViewer.currentItem.userCanPostComment : false
                height: canPost ? sendMsgInput.implicitHeight : 0
                visible: canPost

                color: "lightgray"

                states: [
                    State {
                        name: "maximized"
                        when: sendMsgInput.activeFocus
                        PropertyChanges { target: sendMsgRect; height: visible ? sendMsgInput.implicitHeight + sendMsgColumn.spacing + sendMsgButton.height : 0 }
                    },
                    State {
                        name: "minimized"
                        when: !sendMsgInput.activeFocus
                        PropertyChanges { target: sendMsgRect; height: visible ? sendMsgInput.implicitHeight : 0 }
                    }
                ]

                state: "minimized"

                transitions: [
                    Transition {
                        to: "maximized"
                        NumberAnimation { properties: "height"; easing.type: Easing.OutCubic; duration: 500 }
                    },
                    Transition {
                        to: "minimized"
                        NumberAnimation { properties: "height"; easing.type: Easing.InCubic; duration: 500 }
                    }
                ]

                Column {
                    id: sendMsgColumn
                    spacing: 2
                    anchors {
                        left: parent.left
                        right: parent.right
                        top: parent.top
                    }

                    TextArea {
                        id: sendMsgInput
                        anchors {left: parent.left; right: parent.right}
                        placeholderText: "Комментировать..."
                        textFormat: TextEdit.PlainText
                        wrapMode: TextEdit.Wrap
                    }
                    Button {
                        id: sendMsgButton
                        anchors {right: parent.right}
                        text: "Отправить"
                        onClicked: {
                            commentListModel.sendComment(senderName, senderAvatar, sendMsgInput.text)
                            sendMsgInput.text = ""
                        }
                        enabled: sendMsgInput.text.length > 0
                    }
                }
            }
        }
    }
}
